@@ -120,8 +120,10 @@ const unsigned short ICQ_SNACxLIST_ROSTxEDITxSTART = 0x0011; // client
 const unsigned short ICQ_SNACxLIST_ROSTxEDITxEND   = 0x0012; // client
 const unsigned short ICQ_SNACxLIST_AUTHxREQ2       = 0x0014; // client
 const unsigned short ICQ_SNACxLIST_AUTHxREQ        = 0x0018; // client
+const unsigned short ICQ_SNACxLIST_AUTHxREQxSRV    = 0x0019; // server
 const unsigned short ICQ_SNACxLIST_AUTHxREPLY      = 0x001A; // client
 const unsigned short ICQ_SNACxLIST_AUTHxRESPONS    = 0x001B; // server
+const unsigned short ICQ_SNACxLIST_AUTHxADDED      = 0x001C; // server
 
 // messagetypes
 const unsigned short ICQ_MSGxAUTHORIZE             = 0x0008;
@@ -251,34 +253,52 @@ const unsigned short ICQ_CMDxMETA_RANDOMxSEARCH    = 0x074E; // 1870
 const unsigned short ICQ_CMDxMETA_SETxRANDOMxCHAT  = 0x0758; // 1880
 const unsigned short ICQ_CMDxMETA_SENDxSMS         = 0x1482;
 const unsigned short ICQ_CMDxMETA_WPxINFOxSET      = 0x0C3A;
+const unsigned short ICQ_CMDxMETA_WPxINFOxSET_RSP  = 0x0C3F;
 
 // Meta commands (white page searches) - Jon
 //const unsigned short ICQ_CMDxMETA_SEARCHxWP           = 0x0533; // 1331
 const unsigned short ICQ_CMDxMETA_SEARCHxWPxFOUND     = 0x01A4; // 388
 const unsigned short ICQ_CMDxMETA_SEARCHxWPxLAST_USER = 0x01AE; // 430
 
-// Whitepages Search Commands (BE)
-// used for identifie the field of search after code 0x5F05
-// By SC UIN 27434326 caligore@bigfoot.com
-// step by 0x0a01 why?
+// Whitepage Info Headers (BE)
+const unsigned short ICQ_CMDxWPxWEB_PRESENCE    = 0x0C03;
+const unsigned short ICQ_CMDxWPxHOMEPAGE        = 0x1302;
+const unsigned short ICQ_CMDxWPxTIMEZONE        = 0x1603;
+const unsigned short ICQ_CMDxWPxBIRTHDAY        = 0x3A02;
 const unsigned short ICQ_CMDxWPxFNAME		= 0x4001;
 const unsigned short ICQ_CMDxWPxLNAME		= 0x4A01;
+const unsigned short ICQ_CMDxWPxRECV_ICQ_SPAM   = 0x4803;
 const unsigned short ICQ_CMDxWPxALIAS		= 0x5401;
+const unsigned short ICQ_CMDxWPxABOUT           = 0x5802;
 const unsigned short ICQ_CMDxWPxEMAIL		= 0x5E01;
+const unsigned short ICQ_CMDxWPxHOME_ADDR       = 0x6201;
 const unsigned short ICQ_CMDxWPxAGE		= 0x6801;
+const unsigned short ICQ_CMDxWPxHOME_ZIP        = 0x6D02;
+const unsigned short ICQ_CMDxWPxAGE2            = 0x7201;
+const unsigned short ICQ_CMDxWPxPHONExHOME      = 0x7602;
 const unsigned short ICQ_CMDxWPxGENDER		= 0x7C01;
+const unsigned short ICQ_CMDxWPxHOME_FAX        = 0x8002;
 const unsigned short ICQ_CMDxWPxLANGUAGE	= 0x8601;
+const unsigned short ICQ_CMDxWPxPHONExCELL      = 0x8A02;
 const unsigned short ICQ_CMDxWPxCITY		= 0x9001;
+const unsigned short ICQ_CMDxWPxWORK_ADDR       = 0x9402;
 const unsigned short ICQ_CMDxWPxSTATE		= 0x9A01;
+const unsigned short ICQ_CMDxWPxWORK_CITY       = 0x9E02;
 const unsigned short ICQ_CMDxWPxCOUNTRY		= 0xA401;
+const unsigned short ICQ_CMDxWPxWORK_STATE      = 0xA802;
 const unsigned short ICQ_CMDxWPxCOMPANY		= 0xAE01;
+const unsigned short ICQ_CMDxWPxWORK_COUNTRY    = 0xB202;
 const unsigned short ICQ_CMDxWPxCODEPT		= 0xB801;
+const unsigned short ICQ_CMDxWPxWORK_ZIP        = 0xBD02;
 const unsigned short ICQ_CMDxWPxCOPOS		= 0xC201;
+const unsigned short ICQ_CMDxWPxWORK_PHONE      = 0xC602;
 const unsigned short ICQ_CMDxWPxOCCUP		= 0xCC01;
+const unsigned short ICQ_CMDxWPxWORK_FAX        = 0xD002;
+const unsigned short ICQ_CMDxWPxWORK_URL        = 0xDA02;
 const unsigned short ICQ_CMDxWPxPASTAFF		= 0xD601;
 const unsigned short ICQ_CMDxWPxORGANIZ		= 0xFE01;
 const unsigned short ICQ_CMDxWPxINTEREST	= 0xEA01;
-
+const unsigned short ICQ_CMDxWPxAUTH            = 0xF802;
 const unsigned short ICQ_CMDxWPxKEYWORD		= 0x2602;
 const unsigned short ICQ_CMDxWPxONLINE		= 0x3002;
 
@@ -518,7 +538,20 @@ const char ICQ_CAPABILITY_LICQxVER[]  = { 'L',  'i',  'c',  'q',  ' ',  'c',
                                           'l',  'i',  'e',  'n',  't',  ' ',
                                           0x00, 0x00, 0x00, 0x00 };
  
+const char ICQ_CAPABILITY_SIMxVER[]   = { 'S',  'I',  'M',  ' ',  'c',  'l', 
+                                          'i',  'e',  'n',  't',  ' ',  ' ',
+                                          0x00, 0x00, 0x00, 0x00 };
+
+const char ICQ_CAPABILITY_KOPETExVER[] ={ 'K',  'o',  'p',  'e',  't',  'e',
+                                          ' ',  'I',  'C',  'Q',  ' ',  ' ',
+                                          0x00, 0x00, 0x00, 0x00 };
+
+const char ICQ_CAPABILITY_MICQxVER[]  = { 'm',  'I',  'C',  'Q',  ' ', 0xA9,
+                                          ' ',  'R',  '.',  'K',  '.',  ' ', 
+                                          0x00, 0x00, 0x00, 0x00 };
 // For protocol plugins
+
+// Sending capabilities
 const unsigned long PP_SEND_MSG      = 0x00000001;
 const unsigned long PP_SEND_URL      = 0x00000002;
 const unsigned long PP_SEND_FILE     = 0x00000004;
@@ -528,5 +561,6 @@ const unsigned long PP_SEND_AUTH     = 0x00000020;
 const unsigned long PP_SEND_AUTHxREQ = 0x00000040;
 const unsigned long PP_SEND_SMS      = 0x00000080;
 const unsigned long PP_SEND_SECURE   = 0x00000100;
+const unsigned long PP_SEND_DIRECT   = 0x00000200;
 
 #endif
