@@ -385,7 +385,7 @@ class CPU_AddToServerList : public CPU_CommonFamily
 public:
   CPU_AddToServerList(const char *_szName, unsigned short _nType,
                       unsigned short _nGroup = 0,
-                      bool _bAuthReq = false);
+                      bool _bAuthReq = false, bool _bTopLevel = false);
 
   unsigned short GetSID()   { return m_nSID; }
   unsigned short GetGSID()  { return m_nGSID; }
