@@ -24,6 +24,8 @@
 #include "msnpacket.h"
 #include "licq_log.h"
 #include "licq_message.h"
+#include "licq_translate.h"
+
 
 #include <openssl/md5.h>
 
@@ -38,8 +40,8 @@ void CMSN::ProcessSBPacket(char *szUser, CMSNBuffer *packet, int nSock)
   char szCommand[4];
   CMSNPacket *pReply;
   bool bSkipPacket;
-  
-  while (!packet->End())
+
+  //while (!packet->End())
   {
     pReply = 0;
     bSkipPacket = true;
@@ -145,6 +147,39 @@ void CMSN::ProcessSBPacket(char *szUser, CMSNBuffer *packet, int nSock)
         
         string strType = packet->GetValue("Application-Name");
       }
+      else if (strncmp(strType.c_str(), "application/x-msnmsgrp2p", 24) == 0)
+      {
+	// Get the binary header
+	/*
+	  unsigned long nSessionID = packet->UnpackUnsignedLong();
+	unsigned long nIdentifier = packet->UnpackUnsignedLong();
+	unsigned long nOffset[2], nSize[2], nAckDataSize[2];
+	nOffset[0] = packet->UnpackUnsignedLong();
+	nOffset[1] = packet->UnpackUnsignedLong();
+	nSize[0] = packet->UnpackUnsignedLong();
+	nSize[1] = packet->UnpackUnsignedLong();
+	unsigned long nLen = packet->UnpackUnsignedLong();
+	unsigned long nFlag = packet->UnpackUnsignedLong();
+	unsigned long nAckID = packet->UnpackUnsignedLong();
+	unsigned long nAckUniqueID = packet->UnpackUnsignedLong();
+	nAckDataSize[0] = packet->UnpackUnsignedLong();
+	nAckDataSize[1] = packet->UnpackUnsignedLong();
+
+	printf("%ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld\n",
+	      nSessionID, nIdentifier, nOffset[0], nOffset[1], nSize[0],
+	      nSize[1], nLen, nFlag, nAckID, nAckUniqueID,
+	      nAckDataSize[0], nAckDataSize[1]);
+	*/
+
+	CMSNDataEvent *p = FetchDataEvent(strUser, nSock);
+	if (p)
+	{
+	  if (p->ProcessPacket(packet) > 0)
+	  {
+	    RemoveDataEvent(p);
+	  }
+	}
+      }
     }
     else if (strCmd == "ACK")
     {
@@ -165,7 +200,7 @@ void CMSN::ProcessSBPacket(char *szUser, CMSNBuffer *packet, int nSock)
               ICQUser *u = gUserManager.FetchUser(strUser.c_str(), MSN_PPID, LOCK_R);
               if (u)
               {
-                e->m_pUserEvent->AddToHistory(u, D_SENDER);
+                e->m_pUserEvent->AddToHistory(u, MSN_PPID, D_SENDER);
                 u->SetLastSentEvent();
                 if (strcmp(u->IdString(), e->m_szId) == 0)
                   m_pDaemon->m_xOnEventManager.Do(ON_EVENT_MSGSENT, u);
@@ -178,7 +213,7 @@ void CMSN::ProcessSBPacket(char *szUser, CMSNBuffer *packet, int nSock)
             ICQUser *u = gUserManager.FetchUser(e->m_szId, e->m_nPPID, LOCK_R);
             if (u != NULL)
             {
-              e->m_pUserEvent->AddToHistory(u, D_SENDER);
+              e->m_pUserEvent->AddToHistory(u, MSN_PPID, D_SENDER);
               u->SetLastSentEvent();
               m_pDaemon->m_xOnEventManager.Do(ON_EVENT_MSGSENT, u);
               gUserManager.DropUser(u);
@@ -186,16 +221,33 @@ void CMSN::ProcessSBPacket(char *szUser, CMSNBuffer *packet, int nSock)
           }
           m_pDaemon->m_sStats[STATS_EventsSent].Inc();
         }
+	m_pDaemon->PushPluginEvent(e);
+      }
+      else
+      {
+	// P2P response
+	//packet->SkipRN();
       }
-
-      m_pDaemon->PushPluginEvent(e);
     }
     else if (strCmd == "USR")
     {
+      SStartMessage *pStart = 0;
       pthread_mutex_lock(&mutex_StartList);
-      SStartMessage *pStart = m_lStart.front();
-      pReply = new CPS_MSNCall(pStart->m_szUser);
-      pStart->m_nSeq = pReply->Sequence();
+      StartList::iterator it;
+      for (it = m_lStart.begin(); it != m_lStart.end(); it++)
+      {
+	if ((*it)->m_bConnecting == true)
+	  continue;
+	pStart = *it;
+	break;
+      }
+      
+      if (pStart)
+      {
+	pStart->m_bConnecting = true;
+	pReply = new CPS_MSNCall(pStart->m_szUser);
+	pStart->m_nSeq = pReply->Sequence();
+      }
       pthread_mutex_unlock(&mutex_StartList);
     }
     else if (strCmd == "JOI")
@@ -203,20 +255,6 @@ void CMSN::ProcessSBPacket(char *szUser, CMSNBuffer *packet, int nSock)
       string strUser = packet->GetParameter();
       gLog.Info("%s%s joined the conversation.\n", L_MSNxSTR, strUser.c_str());
 
-      // Add the user to the conversation
-      if (!m_pDaemon->FindConversation(nSock))
-        m_pDaemon->AddConversation(nSock, MSN_PPID);
-        
-      m_pDaemon->AddUserConversation(nSock, strUser.c_str());
-      
-      // Notify the plugins of the new CID
-      m_pDaemon->PushPluginSignal(new CICQSignal(SIGNAL_SOCKET, 0,
-        strdup(strUser.c_str()), MSN_PPID, 0, SocketToCID(nSock)));
-
-      // Notify the plugins
-      m_pDaemon->PushPluginSignal(new
-        CICQSignal(SIGNAL_CONVOxJOIN, 0, strdup(strUser.c_str()), MSN_PPID, 0, SocketToCID(nSock)));
-  
       SStartMessage *pStart = 0;
       StartList::iterator it;
       pthread_mutex_lock(&mutex_StartList);
@@ -230,6 +268,23 @@ void CMSN::ProcessSBPacket(char *szUser, CMSNBuffer *packet, int nSock)
         }
       }
       
+      if ((pStart && pStart->m_bDataConnection == false) || pStart == 0)
+      {
+        // Add the user to the conversation
+        if (!m_pDaemon->FindConversation(nSock))
+          m_pDaemon->AddConversation(nSock, MSN_PPID);
+
+        m_pDaemon->AddUserConversation(nSock, strUser.c_str());
+
+        // Notify the plugins of the new CID
+        m_pDaemon->PushPluginSignal(new CICQSignal(SIGNAL_SOCKET, 0,
+          strdup(strUser.c_str()), MSN_PPID, 0, SocketToCID(nSock)));
+
+        // Notify the plugins
+        m_pDaemon->PushPluginSignal(new
+          CICQSignal(SIGNAL_CONVOxJOIN, 0, strdup(strUser.c_str()), MSN_PPID, 0, SocketToCID(nSock)));
+      }
+
       if (pStart)
       {
         if (pStart->m_pEvent)
@@ -261,7 +316,7 @@ void CMSN::ProcessSBPacket(char *szUser, CMSNBuffer *packet, int nSock)
       if (u)
       {
         u->ClearSocketDesc(ICQ_CHNxNONE);
-        if (!pConv->IsEmpty())
+        if (pConv && !pConv->IsEmpty())
         {
           gUserManager.DropUser(u);
         }
@@ -272,7 +327,8 @@ void CMSN::ProcessSBPacket(char *szUser, CMSNBuffer *packet, int nSock)
           INetSocket *s = gSocketMan.FetchSocket(nThisSock);
           gSocketMan.DropSocket(s);  
           gSocketMan.CloseSocket(nSock);
-          m_pDaemon->RemoveConversation(pConv->CID());
+          if (pConv)
+            m_pDaemon->RemoveConversation(pConv->CID());
         }
       }
     }
@@ -316,7 +372,7 @@ void CMSN::ProcessSBPacket(char *szUser, CMSNBuffer *packet, int nSock)
     }
   }
   
-  delete packet;
+  //delete packet;
 }
 
 void CMSN::Send_SB_Packet(string &strUser, CMSNPacket *p, int nSocket, bool bDelete)
@@ -355,7 +411,8 @@ void CMSN::Send_SB_Packet(string &strUser, CMSNPacket *p, int nSocket, bool bDel
         gUserManager.DropUser(u);
         gSocketMan.DropSocket(s);
         gSocketMan.CloseSocket(nSock);
-        m_pDaemon->RemoveConversation(pConv->CID());
+        if (pConv)
+          m_pDaemon->RemoveConversation(pConv->CID());
       }
     }
   }
@@ -377,9 +434,23 @@ bool CMSN::MSNSBConnectStart(string &strServer, string &strCookie)
     szServer[szPort - szParam] = '\0';
     *szPort++ = '\0';
   }
-  
+
+  SStartMessage *pStart = 0;  
   pthread_mutex_lock(&mutex_StartList);
-  SStartMessage *pStart = m_lStart.front();
+  StartList::iterator it;
+  for (it = m_lStart.begin(); it != m_lStart.end(); it++)
+  {
+    if ((*it)->m_bConnecting == true)
+      continue;
+    pStart = *it;
+    break;
+  }
+  if (!pStart)
+  {
+    pthread_mutex_unlock(&mutex_StartList);
+    return false;
+  }
+  //pStart->m_bConnecting = true;
   TCPSocket *sock = new TCPSocket(pStart->m_szUser, MSN_PPID);
   pthread_mutex_unlock(&mutex_StartList);
 
@@ -400,6 +471,8 @@ bool CMSN::MSNSBConnectStart(string &strServer, string &strCookie)
   ICQUser *u = gUserManager.FetchUser(pStart->m_szUser, MSN_PPID, LOCK_W);
   if (u)
   {
+    if (pStart->m_bDataConnection)
+      sock->SetChannel(ICQ_CHNxINFO);
     u->SetSocketDesc(sock);
     gUserManager.DropUser(u);
   }
@@ -467,6 +540,29 @@ bool CMSN::MSNSBConnectAnswer(string &strServer, string &strSessionId, string &s
   return true;
 }
 
+void CMSN::MSNSendInvitation(char *_szUser, CMSNPacket *_pPacket)
+{
+  //ICQUser *u = gUserManager.FetchUser(_szUser, MSN_PPID, LOCK_R);
+  //if (!u) return;
+  //gUserManager.DropUser(u);
+
+  // Must connect to the SB and call the user
+  CMSNPacket *pSB = new CPS_MSNXfr();
+      
+  SStartMessage *p = new SStartMessage;
+  p->m_pPacket = _pPacket;
+  p->m_pEvent = 0;
+  p->m_pSignal = 0;
+  p->m_szUser = strdup(_szUser);
+  p->m_nSeq = pSB->Sequence();
+  p->m_bConnecting = false;
+  p->m_bDataConnection = true;
+  pthread_mutex_lock(&mutex_StartList);
+  m_lStart.push_back(p);
+  pthread_mutex_unlock(&mutex_StartList);
+  
+  SendPacket(pSB);
+}
 
 void CMSN::MSNSendMessage(char *_szUser, char *_szMsg, pthread_t _tPlugin, unsigned long _nCID)
 {
@@ -484,13 +580,16 @@ void CMSN::MSNSendMessage(char *_szUser, char *_szMsg, pthread_t _tPlugin, unsig
   if (!u) return;
   gUserManager.DropUser(u);
   
-  CMSNPacket *pSend = new CPS_MSNMessage(_szMsg);
-  CEventMsg *m = new CEventMsg(_szMsg, 0, TIME_NOW, 0);
+  char *szRNMsg = gTranslator.NToRN(_szMsg);
+  CMSNPacket *pSend = new CPS_MSNMessage(szRNMsg);
+  CEventMsg *m = new CEventMsg(szRNMsg, 0, TIME_NOW, 0);
   m->m_eDir = D_SENDER;
   ICQEvent *e = new ICQEvent(m_pDaemon, 0, pSend, CONNECT_SERVER, strdup(_szUser), MSN_PPID, m);
   e->thread_plugin = _tPlugin;  
   CICQSignal *s = new CICQSignal(SIGNAL_EVENTxID, 0, strdup(_szUser), MSN_PPID, e->EventId());
   
+  delete [] szRNMsg;
+
   if (nSocket > 0)
   {
     m_pEvents.push_back(e);
@@ -509,6 +608,8 @@ void CMSN::MSNSendMessage(char *_szUser, char *_szMsg, pthread_t _tPlugin, unsig
     p->m_pSignal = s;
     p->m_szUser = strdup(_szUser);
     p->m_nSeq = pSB->Sequence();
+    p->m_bConnecting = false;
+    p->m_bDataConnection = false;
     pthread_mutex_lock(&mutex_StartList);
     m_lStart.push_back(p);
     pthread_mutex_unlock(&mutex_StartList);
@@ -532,21 +633,5 @@ void CMSN::MSNSendTypingNotification(char *_szUser, unsigned long _nCID)
     
   if (nSockDesc > 0)
     Send_SB_Packet(strUser, pSend, nSockDesc);
-#if 0
-  else
-  {
-    // Must connect to the SB and call the user
-    CMSNPacket *pSB = new CPS_MSNXfr();
-      
-    SStartMessage *p = new SStartMessage;
-    p->m_pPacket = pSend;
-    p->m_pEvent = 0;
-    p->m_pSignal = 0;
-    p->m_szUser = strdup(_szUser);
-    m_lStart.push_back(p);
-   
-    SendPacket(pSB);    
-  }
-#endif
 }
 
