@@ -518,7 +518,7 @@ void ProcessSignal(CICQSignal *s)
 			userencoding=u->UserEncoding(); // needed in translate function
             secure=u->Secure();
 
-		    char *username_translated_temp = my_translate(s->Uin(), username.c_str(), userencoding);
+		    char *username_translated_temp = my_translate(s->Uin(), username.c_str(), "UTF-8");
 		    username = username_translated_temp;
 		    delete []username_translated_temp;
 
