@@ -26,6 +26,7 @@
 #include "licq_user.h"
 #include "licqdialog.h"
 #include "gui-defines.h"
+#include "support.h"
 
 #define MSN_PPID 0x4D534E5F
 
@@ -35,7 +36,6 @@ class QTextView;
 class CSignalManager;
 class CQtLogWindow;
 class CSkin;
-class CEmoticons;
 class CICQDaemon;
 class ICQEvent;
 class OptionsDlg;
@@ -137,6 +137,8 @@ public:
        m_bAutoPosReplyWin,
        m_bAutoSendThroughServer,
        m_bEnableMainwinMouseMovement,
+       m_bPopAlias,
+       m_bPopName,
        m_bPopEmail,
        m_bPopPhone,
        m_bPopFax,
@@ -152,7 +154,12 @@ public:
        m_bDisableDockIcon,
        m_bSortColumnAscending,
        m_bAppendLineBreak,
-       m_bFlashTaskbar;
+       m_bFlashTaskbar,
+       m_bMainWinSticky,
+       m_bMsgWinSticky,
+       m_bSingleLineChatMode,
+       m_bCheckSpellingEnabled,
+       m_bShowUserIcons;
 
   QString m_MsgAutopopupKey;
   QString m_DefaultEncoding;
@@ -160,7 +167,6 @@ public:
   ColumnInfos colInfo;
   FlashType m_nFlash;
   CSkin *skin;
-  CEmoticons *emoticons;
 
   unsigned long m_nCurrentGroup, m_nGroupStates;
   unsigned short m_nSortByStatus,
@@ -238,7 +244,7 @@ public:
        *m_szExtendedIconSet;
   QPixmap pmOnline, pmOffline, pmAway, pmDnd, pmOccupied, pmNa,
           pmPrivate, pmFFC, pmMessage, pmUrl, pmChat, pmFile, pmContact, 
-          pmSms, pmAuthorize, pmSMS, pmSecureOn, pmSecureOff, pmHistory, 
+          pmSms, pmAuthorize, pmReqAuthorize, pmSMS, pmSecureOn, pmSecureOff, pmHistory, 
           pmInfo, pmRemove, pmEncoding, pmBirthday, pmPhone, pmCellular, 
           pmInvisible, pmTyping, pmCustomAR, pmCollapsed, pmExpanded, pmSearch,
           pmICQphoneActive, pmICQphoneBusy, pmPhoneFollowMeActive,
@@ -277,6 +283,7 @@ public:
     unsigned short x = 0, unsigned short y = 0, unsigned short w = 0);
   void initMenu();
   bool show_user(ICQUser *);
+  void changeMainWinSticky(bool _bStick);
 
   virtual void resizeEvent (QResizeEvent *);
   virtual void moveEvent(QMoveEvent*);
@@ -382,6 +389,7 @@ protected slots:
                         const QString& filename, const QString& description);
   void sendChatRequest(const char* szId, unsigned long nPPID);
   void addUser(const char* szId, unsigned long nPPID);
+  void setMainWinSticky();
 
 signals:
   void changeDockStatus(unsigned short);
