@@ -40,11 +40,9 @@
 #include <kapp.h>
 #include <kfontdialog.h>
 #include <kurlrequester.h>
-#define DEFAULT_URL_VIEWER tr("KDE default")
 #else
 #include <qapplication.h>
 #include <qfontdialog.h>
-#define DEFAULT_URL_VIEWER tr("none")
 #endif
 
 #include "optionsdlg.h"
@@ -197,6 +195,7 @@ void OptionsDlg::SetupOptions()
   chkShowGroupIfNoMsg->setChecked(mainwin->m_bShowGroupIfNoMsg);
   chkAutoClose->setChecked(mainwin->m_bAutoClose);
   chkTransparent->setChecked(mainwin->skin->frame.transparent);
+  chkShowUserIcons->setChecked(mainwin->m_bShowUserIcons);
   chkScrollBar->setChecked(mainwin->m_bScrollBar);
   chkFlashUrgent->setChecked(mainwin->m_nFlash == FLASH_URGENT || mainwin->m_nFlash == FLASH_ALL);
   chkFlashAll->setChecked(mainwin->m_nFlash == FLASH_ALL);
@@ -209,7 +208,7 @@ void OptionsDlg::SetupOptions()
   edtHotKey->setText(mainwin->m_MsgAutopopupKey);
   chkSysBack->setChecked(mainwin->m_bSystemBackground);
   chkSendFromClipboard->setChecked(mainwin->m_bSendFromClipboard);
-  chkMsgChatView->setChecked( mainwin->m_bMsgChatView );
+  chkMsgChatView->setChecked(mainwin->m_bMsgChatView);
   
   chkLineBreak->setChecked(mainwin->m_bAppendLineBreak);
   cmbStyle->setCurrentItem(mainwin->m_nMsgStyle);
@@ -236,10 +235,16 @@ void OptionsDlg::SetupOptions()
 #endif
     chkShowHistory->setEnabled(false);
   }
+  chkSendTN->setChecked(mainwin->licqDaemon->SendTypingNotification());
   chkAutoPosReplyWin->setChecked(mainwin->m_bAutoPosReplyWin);
   chkFlashTaskbar->setChecked(mainwin->m_bFlashTaskbar);
   chkAutoSendThroughServer->setChecked(mainwin->m_bAutoSendThroughServer);
   chkEnableMainwinMouseMovement->setChecked(mainwin->m_bEnableMainwinMouseMovement);
+  chkMainWinSticky->setChecked(mainwin->m_bMainWinSticky);
+  chkMsgWinSticky->setChecked(mainwin->m_bMsgWinSticky);
+  chkSingleLineChatMode->setChecked(mainwin->m_bSingleLineChatMode);
+  popAlias->setChecked(mainwin->m_bPopAlias);
+  popName->setChecked(mainwin->m_bPopName);
   popEmail->setChecked(mainwin->m_bPopEmail);
   popPhone->setChecked(mainwin->m_bPopPhone);
   popFax->setChecked(mainwin->m_bPopFax);
@@ -510,6 +515,7 @@ void OptionsDlg::ApplyOptions()
   mainwin->m_nFlash = chkFlashAll->isChecked() ? FLASH_ALL :
                       ( chkFlashUrgent->isChecked() ? FLASH_URGENT : FLASH_NONE );
   mainwin->skin->frame.transparent = chkTransparent->isChecked();
+  mainwin->m_bShowUserIcons = chkShowUserIcons->isChecked();
   mainwin->skin->frame.frameStyle = edtFrameStyle->text().toUShort();
   mainwin->m_MsgAutopopupKey = edtHotKey->text();
   mainwin->m_bSystemBackground = chkSysBack->isChecked();
@@ -534,12 +540,19 @@ void OptionsDlg::ApplyOptions()
   mainwin->m_bAutoSendThroughServer = chkAutoSendThroughServer->isChecked();
   mainwin->m_bEnableMainwinMouseMovement = chkEnableMainwinMouseMovement->isChecked();
 
-  mainwin->m_bPopEmail= popEmail->isChecked();
-  mainwin->m_bPopPhone= popPhone->isChecked();
-  mainwin->m_bPopFax= popFax->isChecked();
-  mainwin->m_bPopCellular= popCellular->isChecked();
-  mainwin->m_bPopIP= popIP->isChecked();
-  mainwin->m_bPopLastOnline= popLastOnline->isChecked();
+  mainwin->m_bMainWinSticky = chkMainWinSticky->isChecked();
+  mainwin->changeMainWinSticky(chkMainWinSticky->isChecked());
+  mainwin->m_bMsgWinSticky = chkMsgWinSticky->isChecked();
+  mainwin->m_bSingleLineChatMode = chkSingleLineChatMode->isChecked();
+
+  mainwin->m_bPopAlias = popAlias->isChecked();
+  mainwin->m_bPopName = popName->isChecked();
+  mainwin->m_bPopEmail = popEmail->isChecked();
+  mainwin->m_bPopPhone = popPhone->isChecked();
+  mainwin->m_bPopFax = popFax->isChecked();
+  mainwin->m_bPopCellular = popCellular->isChecked();
+  mainwin->m_bPopIP = popIP->isChecked();
+  mainwin->m_bPopLastOnline = popLastOnline->isChecked();
   mainwin->m_bPopOnlineSince = popOnlineSince->isChecked();
   mainwin->m_bPopIdleTime = popIdleTime->isChecked();
   mainwin->m_bPopID = popID->isChecked();
@@ -614,6 +627,7 @@ void OptionsDlg::ApplyOptions()
     mainwin->m_nDockMode = DockNone;
   }
 
+  mainwin->licqDaemon->SetSendTypingNotification(chkSendTN->isChecked());
   mainwin->licqDaemon->SetUseServerContactList(chkSSList->isChecked());
   mainwin->licqDaemon->SetICQServer(edtICQServer->text().local8Bit());
   mainwin->licqDaemon->SetICQServerPort(spnICQServerPort->value());
@@ -627,7 +641,7 @@ void OptionsDlg::ApplyOptions()
   mainwin->licqDaemon->SetProxyAuthEnabled(chkProxyAuthEnabled->isChecked());
   mainwin->licqDaemon->SetProxyLogin(edtProxyLogin->text().local8Bit());
   mainwin->licqDaemon->SetProxyPasswd(edtProxyPasswd->text().local8Bit());
-  
+
   mainwin->licqDaemon->setReconnectAfterUinClash(chkReconnectAfterUinClash->isChecked());
 
   mainwin->licqDaemon->SetIgnore(IGNORE_NEWUSERS, chkIgnoreNewUsers->isChecked());
@@ -640,9 +654,11 @@ void OptionsDlg::ApplyOptions()
   mainwin->licqDaemon->SetAutoUpdateStatusPlugins(chkAutoUpdateStatusPlugins->isChecked());
 
   // Plugin tab
+#ifdef USE_KDE
   if (cmbUrlViewer->currentText() == DEFAULT_URL_VIEWER)
     mainwin->licqDaemon->setUrlViewer("none");  // untranslated!
   else
+#endif
     mainwin->licqDaemon->setUrlViewer(cmbUrlViewer->currentText().local8Bit());
 
   mainwin->licqDaemon->SetTerminal(edtTerminal->text().local8Bit());
@@ -814,6 +830,10 @@ QWidget* OptionsDlg::new_appearance_options()
   QWhatsThis::add(chkEnableMainwinMouseMovement, tr("Lets you drag around the main window "
    "with your mouse"));
 
+  chkSingleLineChatMode = new QCheckBox(tr("Single line chat mode"), boxMainWin);
+  QWhatsThis::add(chkSingleLineChatMode, tr("In single line chat mode you send messages with Enter "
+    "and insert new lines with Ctrl+Enter, opposite of the normal mode"));
+
   chkMsgChatView = new QCheckBox(tr("Chatmode Messageview"), boxMainWin);
   QWhatsThis::add(chkMsgChatView, tr("Show the current chat history in Send Window"));
 
@@ -827,6 +847,15 @@ QWidget* OptionsDlg::new_appearance_options()
   QWhatsThis::add(chkShowHistory, tr("Show the last 5 messages when a Send Window is opened"));
   connect(chkMsgChatView, SIGNAL(toggled(bool)), this, SLOT(slot_useMsgChatView(bool)));
 
+  chkSendTN = new QCheckBox(tr("Send typing notifications"), boxMainWin);
+  QWhatsThis::add(chkSendTN, tr("Send a notification to the user so they can see when you are typing a message to them"));
+
+  chkMainWinSticky = new QCheckBox(tr("Sticky Main Window"), boxMainWin);
+  QWhatsThis::add(chkMainWinSticky, tr("Makes the Main window visible on all desktops"));
+
+  chkMsgWinSticky = new QCheckBox(tr("Sticky Message Window"), boxMainWin);
+  QWhatsThis::add(chkMsgWinSticky, tr("Makes the Message window visible on all desktops"));
+
   l = new QVBoxLayout(l);
   boxLocale = new QGroupBox(1, Horizontal, tr("Localization"), w);
   lblDefaultEncoding = new QLabel(tr("Default Encoding:"), boxLocale);
@@ -1424,8 +1453,15 @@ QWidget* OptionsDlg::new_column_options()
                                 "<b>status + last event</b> - Sort online users by status and by last event<br>\n"
                                 "<b>status + new messages</b> - Sort online users by status and number of new messages"));
 
+  chkShowUserIcons = new QCheckBox(tr("Show user display picture"), boxUserWin);
+  QWhatsThis::add(chkShowUserIcons, tr("Show the user's display picture"
+				       " instead of a status icon, if the user"
+				       " is online and has a display picture"));
+
   boxPopWin = new QGroupBox(1, Horizontal, tr("Popup info"), w);
 
+  popAlias  = new QCheckBox(tr("Alias"), boxPopWin);
+  popName   = new QCheckBox(tr("Name"),  boxPopWin);
   popEmail  = new QCheckBox(tr("Email"), boxPopWin);
   popPhone  = new QCheckBox(tr("Phone"), boxPopWin);
   popFax    = new QCheckBox(tr("Fax"),   boxPopWin);
@@ -1464,12 +1500,16 @@ QWidget* OptionsDlg::new_misc_options()
   QWhatsThis::add(lblUrlViewer, tr("The command to run to view a URL.  Will be passed the URL "
                                   "as a parameter."));
   cmbUrlViewer = new QComboBox(true, boxExtensions);
+#ifdef USE_KDE
   cmbUrlViewer->insertItem(DEFAULT_URL_VIEWER);
+#endif
+  cmbUrlViewer->insertItem("viewurl-firefox.sh");
   cmbUrlViewer->insertItem("viewurl-lynx.sh");
   cmbUrlViewer->insertItem("viewurl-mozilla.sh");
   cmbUrlViewer->insertItem("viewurl-ncftp.sh");
   cmbUrlViewer->insertItem("viewurl-netscape.sh");
   cmbUrlViewer->insertItem("viewurl-opera.sh");
+  cmbUrlViewer->insertItem("viewurl-seamonkey.sh");
   cmbUrlViewer->insertItem("viewurl-w3m.sh");
 
   lblTerminal = new QLabel(tr("Terminal:"), boxExtensions);
@@ -1594,8 +1634,8 @@ QWidget* OptionsDlg::new_chat_options()
 void OptionsDlg::slot_refresh_msgViewer()
 {
   QDateTime date;
-  char *names[2] = {"Marge", "Homer"};
-  char *msgs[7] = {
+  const char *names[2] = {"Marge", "Homer"};
+  const char *msgs[7] = {
       "This is received message",
       "This is a sent message",
       "Have you gone to the Licq IRC Channel?",
