@@ -21,8 +21,10 @@ class QRadioButton;
 class QTabWidget;
 
 #ifdef USE_KDE
+# define DEFAULT_URL_VIEWER tr("KDE default")
 class KURLRequester;
 #else
+# define DEFAULT_URL_VIEWER "viewurl-mozilla.sh"
 class KURLRequester : public QLineEdit
 {
 public:
@@ -86,13 +88,14 @@ protected:
    QPushButton *btnFont, *btnEditFont;
    QCheckBox *chkSSList, *chkGridLines, *chkHeader, *chkAutoClose,
              *chkShowDividers, *chkFontStyles, *chkUseDock, *chkDockFortyEight,
-             *chkTransparent, *chkShowGroupIfNoMsg,
+             *chkTransparent, *chkShowUserIcons, *chkShowGroupIfNoMsg,
              *chkAutoPopup, *chkAutoRaise, *chkHidden, *chkFlashUrgent, *chkFlashAll,
              *chkBoldOnMsg, *chkManualNewUser,
              *chkAlwaysShowONU, *chkScrollBar, *chkShowExtIcons,
              *chkSysBack, *chkSendFromClipboard, *chkMsgChatView, *chkAutoPosReplyWin,
-	     *chkFlashTaskbar, *chkAutoSendThroughServer, *chkTabbedChatting,
-             *chkEnableMainwinMouseMovement, *chkShowHistory;
+             *chkFlashTaskbar, *chkAutoSendThroughServer, *chkTabbedChatting,
+             *chkMainWinSticky, *chkMsgWinSticky, *chkSingleLineChatMode,
+             *chkEnableMainwinMouseMovement, *chkShowHistory, *chkSendTN;
    QRadioButton *rdbDockDefault, *rdbDockThemed, *rdbDockSmall;
    QComboBox *cmbDockTheme, *cmbSortBy;
 
@@ -132,8 +135,9 @@ protected:
    // display tab
    QWidget* new_popup_options();
    QGroupBox *boxPopWin;
-   QCheckBox *popEmail, *popPhone, *popFax, *popCellular, *popIP,
-	*popLastOnline, *popOnlineSince, *popIdleTime, *popID;
+   QCheckBox *popAlias, *popName, *popEmail, *popPhone,
+             *popFax, *popCellular, *popIP,
+             *popLastOnline, *popOnlineSince, *popIdleTime, *popID;
 
    QWidget* new_chat_options();
    CMessageViewWidget *msgViewer;
