@@ -30,6 +30,8 @@
 #include <qdrawutil.h>
 #include <qregexp.h>
 #include <qstyle.h>
+#include <qimage.h>
+#include <qmime.h>
 
 #include "userbox.moc"
 #include "skin.h"
@@ -40,6 +42,7 @@
 #include "usereventdlg.h"
 #include "usercodec.h"
 
+#include "licq_icqd.h"
 #include "licq_user.h"
 #include "licq_socket.h"
 
@@ -89,6 +92,7 @@ CUserViewItem::CUserViewItem(ICQUser *_cUser, QListView *parent)
   m_nStatus = ICQ_STATUS_OFFLINE;
   m_bGPGKey = false;
   m_bNotInList = _cUser->NotInList();
+  m_pUserIcon = 0;
   setGraphics(_cUser);
 }
 
@@ -122,6 +126,7 @@ CUserViewItem::CUserViewItem (ICQUser *_cUser, CUserViewItem* item)
   m_nStatus = ICQ_STATUS_OFFLINE;
   m_bGPGKey = false;
   m_bNotInList = _cUser->NotInList();
+  m_pUserIcon = 0;
   setGraphics(_cUser);
 }
 
@@ -147,6 +152,7 @@ CUserViewItem::CUserViewItem(unsigned short Id, const char* name, QListView* lv)
   m_nOnlCount = 0;
   m_nEvents = 0;
   m_nStatus = 0;
+  m_pUserIcon = 0;
   // Other users group is sorted at the end
   if (m_nGroupId)
   {
@@ -181,6 +187,7 @@ CUserViewItem::CUserViewItem(BarType barType, QListView *parent)
   m_nWeight = QFont::Normal;
   m_bUrgent = false;
   m_bSecure = false;
+  m_pUserIcon = 0;
   setSelectable(false);
   setHeight(10);
   m_sSortKey = "";
@@ -249,6 +256,9 @@ CUserViewItem::~CUserViewItem()
     delete v->barNotInList;
     v->barNotInList = NULL;
   }
+
+  if (m_pUserIcon)
+    delete m_pUserIcon;
 }
 
 //-----CUserViewItem::setGraphics-----------------------------------------------
@@ -348,6 +358,25 @@ void CUserViewItem::setGraphics(ICQUser *u)
 
    m_pIconStatus = m_pIcon;
 
+   if (u->GetPicturePresent() && m_nStatus != ICQ_STATUS_OFFLINE &&
+       gMainWindow->m_bShowUserIcons)
+   {
+     if (m_pUserIcon == 0)
+     {
+       QString strPath = QString(BASE_DIR) + QString("/") + QString(USER_DIR) +
+	 QString("/") + QString(u->IdString()) + QString(".pic");
+       QImage tmpImg(strPath);
+       if (!tmpImg.isNull())
+       {
+         m_pUserIcon = new QPixmap;
+         *m_pUserIcon  = tmpImg.scale(16, 16);
+       }
+     }
+    
+     if (m_pUserIcon)
+       m_pIcon = m_pUserIcon;
+   }
+
    if (u->NewMessages() > 0)
    {
      m_pIcon = NULL;
@@ -382,6 +411,7 @@ void CUserViewItem::setGraphics(ICQUser *u)
        m_pIcon = &CMainWindow::iconForEvent(SubCommand);
    }
 
+
    m_bFlash = ((u->NewMessages() > 0 && gMainWindow->m_nFlash == FLASH_ALL) ||
        (m_bUrgent && gMainWindow->m_nFlash == FLASH_URGENT));
 
@@ -474,9 +504,9 @@ void CUserViewItem::paintCell( QPainter *p, const QColorGroup & cgdefault, int c
                    strcmp(listView()->onlId, m_szId) == 0 &&
                    listView()->onlPPID == m_nPPID && listView()->onlCounter & 1);
 
-  QColorGroup cg(cgdefault.foreground(), cgdefault.background(),
-    cgdefault.light(), cgdefault.dark(), cgdefault.mid(),
-    onlBlink ? *s_cOffline : *m_cFore, *m_cBack);
+  QColorGroup cg(cgdefault);
+  cg.setColor(QColorGroup::Text, (onlBlink ? *s_cOffline : *m_cFore));
+  cg.setColor(QColorGroup::Base, *m_cBack);
 
   const QPixmap *pix = NULL;
 
@@ -1153,92 +1183,199 @@ void CUserView::viewportDragEnterEvent(QDragEnterEvent* e)
   e->accept(QTextDrag::canDecode(e) || QUriDrag::canDecode(e));
 }
 
+/**
+ * Get a pointer to a dialog for sending events with the given @a type, to the contact
+ * @a szId over the protocol @a nPPID. If the dialog is already open, the dialog is
+ * converted to the correct type before being returned.
+ *
+ * @returns a pointer to a send event dialog of type @a T, or NULL on error.
+ */
+template<typename T>
+static T* getSendEventDialog(UserEventCommon::type type, const char *szId, unsigned long nPPID)
+{
+  int function;
+  if (type == UserEventCommon::UC_CONTACT)
+    function = mnuUserSendContact;
+  else if (type == UserEventCommon::UC_FILE)
+    function = mnuUserSendFile;
+  else if (type == UserEventCommon::UC_MESSAGE)
+    function = mnuUserSendMsg;
+  else if (type == UserEventCommon::UC_URL)
+    function = mnuUserSendUrl;
+  else
+    return NULL;
+
+  UserEventCommon *common = gMainWindow->callFunction(function, szId, nPPID);
+  if (!common)
+    return NULL;
+
+  T *dialog = dynamic_cast<T *>(common);
+  if (!dialog)
+  {
+    UserSendCommon *base = dynamic_cast<UserSendCommon *>(common);
+    if (!base)
+      return NULL;
+
+    base->changeEventType(type);
+    dialog = dynamic_cast<T *>(gMainWindow->callFunction(function, szId, nPPID));
+    if (!dialog)
+      return NULL;
+  }
+
+  return dialog;
+}
+
+/// Convenient, wrapper functions for getSendEventDialog.
+static inline UserSendContactEvent* getSendContactEventDialog(const char *szId, unsigned long nPPID)
+{
+  return getSendEventDialog<UserSendContactEvent>(UserEventCommon::UC_CONTACT, szId, nPPID);
+}
+
+static inline UserSendFileEvent* getSendFileEventDialog(const char *szId, unsigned long nPPID)
+{
+  return getSendEventDialog<UserSendFileEvent>(UserEventCommon::UC_FILE, szId, nPPID);
+}
+
+static inline UserSendMsgEvent* getSendMsgEventDialog(const char *szId, unsigned long nPPID)
+{
+  return getSendEventDialog<UserSendMsgEvent>(UserEventCommon::UC_MESSAGE, szId, nPPID);
+}
+
+static inline UserSendUrlEvent* getSendUrlEventDialog(const char *szId, unsigned long nPPID)
+{
+  return getSendEventDialog<UserSendUrlEvent>(UserEventCommon::UC_URL, szId, nPPID);
+}
 
 void CUserView::viewportDropEvent(QDropEvent* e)
 {
+  // We ignore the event per default and then accept it if we
+  // get to the end of this function.
+  e->ignore();
+
   CUserViewItem* it = static_cast<CUserViewItem*>(itemAt(e->pos()));
+  if (!it)
+    return;
 
-  if(it)
+  if (it->ItemId())
   {
-    if (it->ItemId())
+    QString text;
+    QStrList lst;
+    if (QUriDrag::decode(e, lst))
     {
-      QString text;
-      QStrList lst;
-      if(QUriDrag::decode(e, lst))
+      QStrListIterator strIter(lst);
+      if (!(text = QUriDrag::uriToLocalFile(strIter)).isEmpty())
       {
-        QStrListIterator strIter(lst);
-        if(!(text = QUriDrag::uriToLocalFile(strIter)).isEmpty())
+        UserSendFileEvent *sendFile = getSendFileEventDialog(it->ItemId(), it->ItemPPID());
+        if (!sendFile)
+          return;
+
+        sendFile->setFile(text, QString::null);
+
+        // Add all the files
+        while (strIter != lst.getLast())
         {
-          UserSendFileEvent *e = static_cast<UserSendFileEvent *>
-            (gMainWindow->callFunction(mnuUserSendFile, it->ItemId(),
-                it->ItemPPID()));
-          e->setFile(text, QString::null);
-          
-          // Add all the files
-          while (strIter != lst.getLast())
-          {
-            ++strIter;
-            if (!(text = QUriDrag::uriToLocalFile(strIter)).isEmpty())
-              e->addFile(text);
-          }
-          
-          e->show();
-        }
-        else
-        {
-          UserSendUrlEvent *e = static_cast<UserSendUrlEvent *>
-            (gMainWindow->callFunction(mnuUserSendUrl, it->ItemId(),
-                it->ItemPPID()));
-          e->setUrl(text, QString::null);
-          e->show();
+          ++strIter;
+          if (!(text = QUriDrag::uriToLocalFile(strIter)).isEmpty())
+            sendFile->addFile(text);
         }
+
+        sendFile->show();
       }
-      
-      //TODO change this
-      else if(QTextDrag::decode(e, text)) {
-//        const char *p = (text.left(4).latin1());
-        char *szId = strdup((text.mid(4, text.length() - 4).latin1()));
-        unsigned long nPPID = LICQ_PPID; //TODO fix this
+      else
+      {
+        UserSendUrlEvent *sendUrl = getSendUrlEventDialog(it->ItemId(), it->ItemPPID());
+        if (!sendUrl)
+          return;
 
-        if(szId) {
-          if(strcmp(szId, it->ItemId()) == 0 && nPPID == it->ItemPPID()) return;
-          UserSendContactEvent* e = static_cast<UserSendContactEvent*>
-            (gMainWindow->callFunction(mnuUserSendContact, it->ItemId(), it->ItemPPID()));
-          ICQUser* u = gUserManager.FetchUser(szId, nPPID, LOCK_R);
-          QString alias = u ? u->GetAlias() : "";
-          gUserManager.DropUser(u);
-
-          e->setContact(szId, nPPID, alias);
-          e->show();
-        }
-        else {
-          UserSendMsgEvent* e = static_cast<UserSendMsgEvent*>
-            (gMainWindow->callFunction(mnuUserSendMsg, it->ItemId(), it->ItemPPID()));
-          e->setText(text);
-          e->show();
-        }
-
-        free (szId);
+        sendUrl->setUrl(QString(strIter), QString::null);
+        sendUrl->show();
       }
     }
-    //TODO Change this
-    else if(it->isGroupItem())
-    {
-      QString text;
-      if(QTextDrag::decode(e, text)) {
-//        const char *p = (text.left(4).latin1());
-        char *szId = strdup(text.mid(4, text.length() - 4).latin1());
-        unsigned long nPPID = LICQ_PPID; //TODO Fix this
 
-        if(szId) {
-          gUserManager.AddUserToGroup(szId, nPPID, it->GroupId());
-          gMainWindow->updateUserWin();
+    else if (QTextDrag::decode(e, text))
+    {
+      unsigned long nPPID = 0;
+      FOR_EACH_PROTO_PLUGIN_START(gMainWindow->licqDaemon)
+      {
+        if (text.startsWith(PPIDSTRING((*_ppit)->PPID())))
+        {
+          nPPID = (*_ppit)->PPID();
+          break;
         }
+      }
+      FOR_EACH_PROTO_PLUGIN_END;
+
+      if (nPPID && text.length() > 4)
+      {
+        char *szId = strdup(text.mid(4).latin1());
+        if (strcmp(szId, it->ItemId()) == 0 && nPPID == it->ItemPPID())
+        {
+          free(szId);
+          return;
+        }
+
+        UserSendContactEvent* sendContact = getSendContactEventDialog(it->ItemId(), it->ItemPPID());
+        if (!sendContact)
+        {
+          free(szId);
+          return;
+        }
+
+        ICQUser* u = gUserManager.FetchUser(szId, nPPID, LOCK_R);
+        QString alias = u ? u->GetAlias() : "";
+        gUserManager.DropUser(u);
+
+        sendContact->setContact(szId, nPPID, alias);
+        sendContact->show();
 
         free(szId);
       }
+      else
+      {
+        UserSendMsgEvent* sendMsg = getSendMsgEventDialog(it->ItemId(), it->ItemPPID());
+        if (!sendMsg)
+          return;
+
+        sendMsg->setText(text);
+        sendMsg->show();
+      }
     }
   }
+
+  else if (it->isGroupItem())
+  {
+    QString text;
+    if (QTextDrag::decode(e, text) && text.length() > 4)
+    {
+      unsigned long nPPID = 0;
+      FOR_EACH_PROTO_PLUGIN_START(gMainWindow->licqDaemon)
+      {
+        if (text.startsWith(PPIDSTRING((*_ppit)->PPID())))
+        {
+          nPPID = (*_ppit)->PPID();
+          break;
+        }
+      }
+      FOR_EACH_PROTO_PLUGIN_END;
+
+      if (nPPID == 0)
+        return;
+
+      char *szId = strdup(text.mid(4).latin1());
+
+      if (szId)
+      {
+        gUserManager.AddUserToGroup(szId, nPPID, it->GroupId());
+        gMainWindow->updateUserWin();
+      }
+
+      free(szId);
+    }
+    else
+      return; // Not accepted
+  }
+
+  e->accept();
 }
 
 
@@ -1260,7 +1397,8 @@ void CUserView::keyPressEvent(QKeyEvent *e)
       CUserViewItem* item = static_cast<CUserViewItem*>(currentItem());
       if(item == NULL) return;
 
-      if(item->isGroupItem()) {
+      if(item->isGroupItem())
+      {
         setOpen(item, !item->isOpen());
         return;
       }
@@ -1291,7 +1429,8 @@ void CUserView::keyPressEvent(QKeyEvent *e)
 
       QListViewItemIterator it(this);
       QListViewItem* lastitem = 0;
-      while(it.current() != NULL) {
+      while(it.current() != NULL)
+      {
         lastitem = it.current();
         ++it;
       }
@@ -1309,18 +1448,18 @@ void CUserView::keyPressEvent(QKeyEvent *e)
       if (m_typePos > 0)
       {
         m_typeAhead.truncate(m_typeAhead.length()-1);
-	m_typePos--;
+        m_typePos--;
       }
       /* fall through */
-      
+
     default:
     {
       int ascii = tolower(e->ascii());
       if (!isalnum(ascii) && e->key() != Key_Backspace)
       {
         QListView::keyPressEvent(e);
-	m_typeAhead = "";
-	m_typePos = 0 ;
+        m_typeAhead = "";
+        m_typePos = 0 ;
         return;
       }
 
@@ -1328,20 +1467,18 @@ void CUserView::keyPressEvent(QKeyEvent *e)
       m_typePos++;
 
       QListViewItemIterator it(firstChild());
-      
+
       while (it.current() != NULL)
       {
         CUserViewItem* item = static_cast<CUserViewItem*>(it.current());
+        if (item->text(1).lower().startsWith(m_typeAhead))
         {
-	  if (item->text(1).lower().startsWith(m_typeAhead))
-	  {
-            setSelected(item, true);
-            ensureItemVisible(item);
-	    item->repaint();
-            return;
-          }
-          ++it;
+          setSelected(item, true);
+          ensureItemVisible(item);
+          item->repaint();
+          return;
         }
+        ++it;
       }
 
       // If we are here we didn't find any names
@@ -1538,8 +1675,37 @@ void CUserView::maybeTip(const QPoint& c)
   if (item && item->m_szId)
   {
     QRect r(itemRect(item));
-    QString s = QString("<nobr>") + QString(ICQUser::StatusToStatusStr(item->m_nStatus, item->m_bStatusInvisible))
+    ICQUser *u = gUserManager.FetchUser(item->m_szId, item->m_nPPID, LOCK_R);
+    QTextCodec * codec = UserCodec::codecForICQUser(u);
+    QString strFileName = "";
+    if (u && u->GetPicturePresent())
+    {
+      const QString file = QString("%1/%2/%3.pic").arg(BASE_DIR).arg(USER_DIR).arg(u->IdString());
+      const QImage picture = QImage(file);
+      if (!picture.isNull())
+      {
+        QMimeSourceFactory::defaultFactory()->setImage(file, picture);
+        strFileName = QString("<center><img src=\"%1\"></center>").arg(file);
+      }
+    }
+
+    QString s = strFileName + QString("<nobr>") + QString(ICQUser::StatusToStatusStr(item->m_nStatus, item->m_bStatusInvisible))
       + QString("</nobr>");
+    
+    if (*u->GetAlias() && gMainWindow->m_bPopAlias)
+      s += tr("<br><nobr>") + QString::fromUtf8(u->GetAlias()) + tr("</nobr>");
+
+    if ((*u->GetFirstName() || *u->GetLastName()) && gMainWindow->m_bPopName)
+    {
+      s += tr("<br><nobr>");
+      if (*u->GetFirstName())
+        s += codec->toUnicode(u->GetFirstName());
+      if (*u->GetFirstName() && *u->GetLastName())
+        s += " ";
+      if (*u->GetLastName())
+        s += codec->toUnicode(u->GetLastName());
+      s += tr("</nobr>");
+    }
 
     if (item->m_nStatusFull & ICQ_STATUS_FxBIRTHDAY)
       s += tr("<br><b>Birthday&nbsp;Today!</b>");
@@ -1568,8 +1734,6 @@ void CUserView::maybeTip(const QPoint& c)
     if (item->m_bCustomAR)
       s += tr("<br>Custom&nbsp;Auto&nbsp;Response");
 
-    ICQUser *u = gUserManager.FetchUser(item->m_szId, item->m_nPPID, LOCK_R);
-    QTextCodec * codec = UserCodec::codecForICQUser(u);
     if (u != NULL)
     {
       if (!u->StatusOffline() && u->ClientInfo() && *u->ClientInfo())
