@@ -116,6 +116,9 @@ void IconManager::X11Init()
   setMask(*wharfIcon->vis->mask());
   move(-100,-100);
   show();
+#ifndef USE_KDE
+  XWithdrawWindow(dsp, win, XScreenNumberOfScreen(DefaultScreenOfDisplay(dsp)));
+#endif
 }
 
 
@@ -810,3 +813,5 @@ void WharfIcon::paintEvent( QPaintEvent * )
   painter.drawPixmap(0, 0, *vis);
   painter.end();
 }
+
+#include "wharf.moc"
