@@ -38,6 +38,9 @@
 extern int errno;
 #endif
 
+// Localization
+#include "gettext.h"
+
 #include "licq_icq.h"
 #include "licq_user.h"
 #include "licq_constants.h"
@@ -59,55 +62,64 @@ extern int errno;
 #define ReportBadBuddy(cmdname,szUin) \
   (gLog.Info("%s `%s': bad buddy string `%s'\n",L_FIFOxSTR,cmdname,szUin))
 
-static const char* const HELP_STATUS = 
+static const char* const HELP_STATUS = tr(
         "\tstatus <[*]<status>> <auto response>\n"
         "\t\tstatus: online, offline, na, away, occupied, dnd, ffc\n\n"
         "\t\tSets the status of the current Licq session\n"
         "\t\tto that given (precede the status by a\n"
-        "\t\t\"*\" for invisible mode)\n";
-static const char* const HELP_AUTO = 
+        "\t\t\"*\" for invisible mode)\n");
+static const char* const HELP_AUTO = tr(
         "\tauto_response <auto response>\n"
         "\t\tSets the auto response message without\n"
-        "\t\tchanging the current status.\n";
-static const char* const HELP_MSG =
+        "\t\tchanging the current status.\n");
+static const char* const HELP_MSG = tr(
         "\tmessage <buddy> <message>\n"
-        "\t\tSend a message to the given buddy.\n";
-static const char* const HELP_URL = 
+        "\t\tSend a message to the given buddy.\n");
+static const char* const HELP_URL = tr(
         "\turl <buddy> <url> [<description>]\n"
-        "\t\tSend a url to the given buddy.\n";
-static const char* const HELP_SMS =
+        "\t\tSend a url to the given buddy.\n");
+static const char* const HELP_SMS = tr(
         "\tsms <buddy> <message>\n"
-        "\tSend a SMS to the given buddy.\n";
-static const char* const HELP_SMS_NUMBER =
+        "\tSend a SMS to the given buddy.\n");
+static const char* const HELP_SMS_NUMBER = tr(
         "\tsms <number> <message>\n"
-        "\tSend a SMS to the given cellular number.\n";
-static const char* const HELP_REDIRECT = 
+        "\tSend a SMS to the given cellular number.\n");
+static const char* const HELP_REDIRECT = tr(
         "\tredirect <file>\n"
         "\t\tRedirects stderr for\n"
-        "\t\tLicq to the given file.\n";
-static const char* const HELP_DEBUGLVL = 
+        "\t\tLicq to the given file.\n");
+static const char* const HELP_DEBUGLVL = tr(
         "\tdebuglvl <level>\n"
         "\t\tSet what information is logged.\n"
-        "\t\tSee <level> in licq -h\n";
-static const char* const HELP_ADDUSER = 
+        "\t\tSee <level> in licq -h\n");
+static const char* const HELP_ADDUSER = tr(
         "\tadduser <uin>\n"
-        "\t\tAdd user with <uin> to your contact list.\n";
-static const char* const HELP_USERINFO = 
+        "\t\tAdd user with <uin> to your contact list.\n");
+static const char* const HELP_USERINFO = tr(
         "\tuserinfo <buddy>\n"
-        "\t\tUpdates a buddy's user information.\n";
-static const char* const HELP_EXIT =
+        "\t\tUpdates a buddy's user information.\n");
+static const char* const HELP_EXIT = tr(
         "\texit\n"
-        "\t\tCauses the Licq session to shutdown.\n";
-static const char* const HELP_UIVIEWEVENT = 
+        "\t\tCauses the Licq session to shutdown.\n");
+static const char* const HELP_UIVIEWEVENT = tr(
         "\tui_viewevent [<buddy>]\n"
-        "\t\tShows the oldest pending event.\n";
-static const char* const HELP_UIMESSAGE =
+        "\t\tShows the oldest pending event.\n");
+static const char* const HELP_UIMESSAGE = tr(
         "\tui_message <buddy>\n"
-        "\t\tOpen the plugin message composer to <buddy>\n";
-static const char* const HELP_HELP = 
-        "\thelp <command>\n" 
-        "\t\tPrint help information for <command>.\n";
-
+        "\t\tOpen the plugin message composer to <buddy>\n");
+static const char* const HELP_PLUGINLIST = tr(
+		"\tlist_plugins\n"
+		"\t\tLists the loaded UI plugins\n");
+static const char* const HELP_PLUGINLOAD = tr(
+		"\tload_plugin <plugin>\n"
+		"\t\tLoads the UI plugin called <plugin>\n");
+static const char* const HELP_PLUGINUNLOAD = tr(
+		"\tunload_plugin <plugin>\n"
+		"\t\tUnloads the UI plugin called <plugin>.\n"
+		"\t\tUse list_plugins to see currently loaded UI plugins.\n");
+static const char* const HELP_HELP = tr(
+        "\thelp <<command> | all>\n" 
+        "\t\tPrint help information for <command> or for all commands.\n");
 #define MAX_ARGV 64
 
 enum 
@@ -160,46 +172,155 @@ StringToStatus(char *_szStatus)
 }
 
 
-/*! \brief Given an ascii string get the uin
+static bool buffer_is_uin(const char *buffer)
+{
+  unsigned len = 0;
+  
+  for( ; buffer && isdigit(*buffer) ; buffer++ , len++ )
+    ;
+
+  return (len>0 && len <= MAX_UIN_DIGITS) && *buffer=='\0';
+}
+
+static bool buffer_get_ids(CICQDaemon *d, char *buffer, 
+                           char **szId, unsigned long *nPPID, 
+                           bool *missing_protocol)
+{
+  bool found = false;
+  char *write = buffer;
+
+  *missing_protocol = true;
+  *szId = write;
+  for( ; *buffer && !found ; buffer++ )
+  {
+    if( *buffer == '@' ) 
+    {
+      if( *(buffer+1)== '@' ) // @@ -> @
+      {
+        buffer++;
+        *write = '@';
+        write++;
+      }
+      else
+        found = true;
+    }
+    else
+    {
+      *write = *buffer;
+      write++;
+    }
+  }
+  *write = 0;
+  
+  if( found )
+  { 
+    ProtoPluginsList l;
+    ProtoPluginsListIter it;
+
+    found = false;
+    *missing_protocol = false;
+    
+    d->ProtoPluginList(l);
+    for( it = l.begin() ; !found && it != l.end() ; ++it)
+    {
+      if( !strcmp( (*it)->Name(), buffer) )
+      {
+        *nPPID = (*it)->PPID();
+        found = true;
+      }
+    }
+  }
+
+  return found;
+}
+
+/*! \brief Given an ascii string gets the szId and the nPPID
  *
- *  Given an ascii string get the uin
- *  1. If all chars are digits then:
- *    a) if bList flag is on, check if it is in the list
- *    b) else return 
- *  2. If that fail try with alias Params.
+ *  -# If all chars are digits then:
+ *    -# assume it is a uin, and if bList flag is on, then check if it 
+ *       is in the list
+ *  -# If that fail try with alias Params.
  * 
- *  \param  buff     buffer to convert
- *  \param  bOnList  fail if buff is an uin number and it is not in user list
- *  \param  nUin     address where the uin is saved
+ *  \param  buff     string to convert
+ *  \param  bOnList  fail if #buff is not in the list
+ *  \param  szId     address where the szId is returned
+ *  \param  nPPID    address where the nPPID is returned
  *
  * \returns true on success
  */
-bool atouin( const char *buff, bool bOnList, unsigned long *nUin)
-{
-  const char *p;
-
+static bool atoid( const char *buff, bool bOnList, 
+                   char **szId, unsigned long *nPPID,
+                   CICQDaemon *daemon)
+{ 
+  char *_szId = 0;
+  unsigned long _nPPID = 0;
+  bool ret = false, missing_protocol=true;
+  char *s = 0;
+  
   if (buff == NULL) 
-    return false; 
-
-  for( p=buff; isdigit(*p) ; p++ )
-    ;
-  if( *p == '\0' && bOnList && gUserManager.IsOnList(atol(buff)) || 
-      *p == '\0' && !bOnList)
-    *nUin = atol(buff);
-  else
+    ret = false; 
+  else if( (s=strdup(buff)) == 0 )
+    ret  = false;
+  else if ( buffer_is_uin(buff) && 
+           ((bOnList && gUserManager.IsOnList(buff, LICQ_PPID)) || !bOnList  ))
   {
-    *nUin = 0; 
-    FOR_EACH_USER_START(LOCK_R)
+    _nPPID = LICQ_PPID;
+    _szId = s;
+    ret = true;
+  }
+  else if( buffer_get_ids(daemon, s, &_szId, &_nPPID, &missing_protocol) )
+  {
+    ret = false;
+
+    FOR_EACH_PROTO_USER_START(_nPPID, LOCK_R)
     {
-      if (strcasecmp(buff, pUser->GetAlias()) == 0)
+      if( strcasecmp(_szId, pUser->GetAlias()) == 0)
       {
-        *nUin = pUser->Uin();
-        FOR_EACH_USER_BREAK;
+        _szId = strdup(pUser->IdString());
+        ret = true;
+        FOR_EACH_PROTO_USER_BREAK
       }
     }
-    FOR_EACH_USER_END
+    FOR_EACH_PROTO_USER_END
   }
-  return !(*nUin == 0);
+  else if( missing_protocol )
+  {  
+     /* assume ICQ */
+    _nPPID = LICQ_PPID;
+    
+    FOR_EACH_PROTO_USER_START(_nPPID, LOCK_R)
+    {
+        if( strcasecmp(s, pUser->GetAlias()) == 0)
+        {
+          _szId = (char *) malloc(26);
+          if( _szId )
+          { 
+            sprintf(_szId, "%ld", pUser->Uin() );
+            ret = true;
+          }
+          FOR_EACH_PROTO_USER_BREAK
+        }
+    }
+    FOR_EACH_PROTO_USER_END
+    free(s);
+    s = 0;
+  }
+  else
+  {
+    free(s);
+    s = 0;
+    ret = false;
+  }
+
+  if( ret )
+  {
+    if( szId )
+      *szId = _szId;
+    if( nPPID )
+      *nPPID = _nPPID;
+  }
+  
+  return ret;
 }
 
 // status 
@@ -225,7 +346,7 @@ static int fifo_status( int argc, const char *const *argv, void *data)
 
   if (nStatus == INT_MAX)
   {
-    gLog.Warn("%s%s %s: command with invalid status \"%s\".\n",
+    gLog.Warn(tr("%s%s %s: command with invalid status \"%s\".\n"),
               L_WARNxSTR,L_FIFOxSTR,argv[0],szStatus);
     return -1;
   }
@@ -275,8 +396,8 @@ static int fifo_auto_response( int argc, const char *const *argv, void *data)
 static int fifo_message ( int argc, const char *const *argv, void *data)
 {
   CICQDaemon *d = (CICQDaemon *) data;;
-  unsigned long nUin; 
-  const char *szUin = argv[1];
+  unsigned long nPPID;
+  char *szId = 0;
 
   if( argc < 3 )
   {
@@ -284,10 +405,13 @@ static int fifo_message ( int argc, const char *const *argv, void *data)
     return -1;
   }
 
-  if( atouin(szUin,false,&nUin) )
-    d->icqSendMessage(nUin, argv[2], false, false);
+  if( atoid(argv[1], false, &szId, &nPPID, d) )
+    d->ProtoSendMessage(szId, nPPID, argv[2], false, 0);
+
   else
-    ReportBadBuddy(argv[0],szUin);
+    ReportBadBuddy(argv[0], argv[1]);
+
+  free(szId);
 
   return 0;
 }
@@ -295,9 +419,10 @@ static int fifo_message ( int argc, const char *const *argv, void *data)
 // url <buddy> <url> [<description>]
 static int fifo_url ( int argc, const char *const *argv, void *data)
 {
-  unsigned long nUin;
   const char *szDescr;
   CICQDaemon *d = (CICQDaemon *) data;
+  unsigned long nPPID;
+  char *szId = 0;
 
   if( argc < 3 )
   {
@@ -305,14 +430,16 @@ static int fifo_url ( int argc, const char *const *argv, void *data)
     return -1;
   }
 
-  if( atouin (argv[1],false,&nUin) )
+  if( atoid(argv[1], false, &szId, &nPPID, d) )
   {
     szDescr = (argc > 3) ? argv[3] : "" ;
-    d->icqSendUrl(nUin, argv[2], szDescr, false, false);
+    d->ProtoSendUrl(szId, nPPID, argv[2], szDescr, false, false);
   }
   else
     ReportBadBuddy(argv[0],argv[1]);
 
+  free(szId);
+
   return 0;
 }
 
@@ -320,8 +447,8 @@ static int fifo_url ( int argc, const char *const *argv, void *data)
 static int fifo_sms(int argc, const char *const *argv, void *data)
 {
   CICQDaemon *d = (CICQDaemon *) data;
-  unsigned long nUin;
-  const char *szUin = argv[1];
+  unsigned long nPPID;
+  char *szId = 0;
 
   if (argc < 3)
   {
@@ -329,22 +456,30 @@ static int fifo_sms(int argc, const char *const *argv, void *data)
     return -1;
   }
 
-  if (atouin(szUin, false, &nUin))
-  {
-    ICQUser *u = gUserManager.FetchUser(nUin, LOCK_R);
-    if (u != NULL)
+  if (atoid(argv[1], false, &szId, &nPPID, d) )
+  { 
+    if( nPPID == LICQ_PPID )
     {
-      const char *szNumber = u->GetCellularNumber();
-      if (strlen(szNumber))
-        d->icqSendSms(szNumber, argv[2], nUin);
-      else
-        gLog.Error("%sUnable to send SMS to %lu, no SMS number found.\n", L_ERRORxSTR, nUin);
+      ICQUser *u = gUserManager.FetchUser(szId, nPPID, LOCK_R);
+      if (u != NULL)
+      {
+        const char *szNumber = u->GetCellularNumber();
+        if (strlen(szNumber))
+          d->icqSendSms(szNumber, argv[2], u->Uin() );
+        else
+          gLog.Error("%sUnable to send SMS to %s, no SMS number found.\n",
+                     L_ERRORxSTR, szId);
 
-      gUserManager.DropUser(u);
+        gUserManager.DropUser(u);
+      }
     }
+    else
+      gLog.Info(tr("%s `%s': bad protol. ICQ only alowed\n"), L_FIFOxSTR, argv[0]);
   }
   else
-    ReportBadBuddy(argv[0],szUin);
+    ReportBadBuddy(argv[0], argv[1]);
+
+  free(szId);
 
   return 0;
 }
@@ -375,14 +510,14 @@ static int fifo_redirect ( int argc, const char *const *argv, void *data)
     return -1;
   }
 
-  // TODO: its safe to call strerror ?
   if ( !Redirect(argv[1]) )
   {
-    gLog.Warn("%s %s: redirection to \"%s\" failed: %s.\n",
+    gLog.Warn(tr("%s %s: redirection to \"%s\" failed: %s.\n"),
               L_WARNxSTR,argv[0], argv[1],strerror(errno));
   }
   else
-    gLog.Info("%s %s: output redirected to \"%s\".\n", L_INITxSTR, argv[0],argv[1]);
+    gLog.Info(tr("%s %s: output redirected to \"%s\".\n"), L_INITxSTR, argv[0],
+             argv[1]);
 
   return 0;
 }
@@ -402,9 +537,10 @@ static int fifo_debuglvl ( int argc, const char *const *argv, void *data)
 
 // adduser <buddy>
 static int fifo_adduser ( int argc, const char *const *argv, void *data)
-{
-  unsigned long nUin;
+{ 
   CICQDaemon *d = (CICQDaemon *) data;
+  unsigned long nPPID;
+  char *szId = 0;
 
   if( argc  == 1 )
   {
@@ -412,10 +548,11 @@ static int fifo_adduser ( int argc, const char *const *argv, void *data)
     return -1;
   }
 
-  if( atouin(argv[1],false,&nUin) )
-    d->AddUserToList(nUin);
+  if( atoid(argv[1], false, &szId, &nPPID, d) )
+    d->AddUserToList(szId, nPPID);
   else
     ReportBadBuddy(argv[0],argv[1]);
+  free(szId);
 
   return 0;
 }
@@ -423,33 +560,36 @@ static int fifo_adduser ( int argc, const char *const *argv, void *data)
 // userinfo <buddy>
 static int fifo_userinfo ( int argc, const char *const *argv, void *data)
 {
-  unsigned long nUin;
-  ICQUser *u;
   CICQDaemon *d = (CICQDaemon *) data;
+  unsigned long nPPID;
+  char *szId = 0; 
+  ICQUser *u;
+  int ret = -1; 
 
   if ( argc == 1 )
-  {
     ReportMissingParams(argv[0]);
-    return -1;
-  }
-
-  if( !atouin(argv[1],true,&nUin) )
-  {
+  else if( !atoid(argv[1], true, &szId, &nPPID, d) )
     ReportBadBuddy(argv[0],argv[1]);
-    return -1;
-  }
-
-  u = gUserManager.FetchUser(nUin, LOCK_R);
-  if (u == NULL)
-    gLog.Warn("%s %s: user %ld not on contact list, not retrieving"
-              "info.\n", L_WARNxSTR,argv[0],nUin);
+  else if( nPPID != LICQ_PPID )
+     gLog.Info(tr("%s `%s': bad protol. ICQ only alowed\n"), L_FIFOxSTR, argv[0]);
   else
   {
-    gUserManager.DropUser(u);
-    d->icqRequestMetaInfo(nUin);
+    u = gUserManager.FetchUser(szId, nPPID, LOCK_R);
+    if (u == NULL)
+      gLog.Warn(tr("%s %s: user %s not on contact list, not retrieving "
+                "info.\n"), L_WARNxSTR, argv[0], szId);
+    else
+    {
+      unsigned long nUin = u->Uin();
+      gUserManager.DropUser(u);
+      d->icqRequestMetaInfo(nUin);
+      ret = 0;
+    }
   }
-
-  return 0;
+  
+  free( szId );
+  
+  return ret;
 }
 
 // exit
@@ -464,18 +604,28 @@ static int fifo_exit ( int argc, const char *const *argv, void *data)
 static int fifo_ui_viewevent ( int argc, const char *const *argv, void *data)
 {
   CICQDaemon *d = (CICQDaemon *) data; 
-  unsigned long nUin;
-
-  if( argc ==1 )
-    nUin = 0;
-  else if( !atouin(argv[1],true,&nUin) )
-  {
-    ReportBadBuddy(argv[0],argv[1]);
-    return -1;
-  }
-
-  d->PluginUIViewEvent(nUin);
+  unsigned long nPPID;
+  char *szId = 0; 
+  char *none = "0";
   
+  if( argc ==1 )
+  {
+    szId = none;
+    nPPID = 0;
+  }
+  else if( !atoid(argv[1], true, &szId, &nPPID, d) )
+  {  
+    ReportBadBuddy(argv[0],argv[1]);
+    free(szId);
+
+    return 0;
+  }
+  
+  d->PluginUIViewEvent(szId, nPPID);
+
+  if( szId != none )
+    free(szId);
+
   return 0;
 }
 
@@ -483,25 +633,86 @@ static int fifo_ui_viewevent ( int argc, const char *const *argv, void *data)
 static int fifo_ui_message ( int argc, const char *const *argv, void *data)
 {
   CICQDaemon *d = (CICQDaemon *) data;
-  unsigned long nUin;
-  int nRet=0;
+  unsigned long nPPID = 0;
+  char *szId = 0;
+  int nRet = 0;
 
   if ( argc == 1 )
   {
     ReportMissingParams(argv[0]);
     nRet = -1;
-  } 
-  else if( atouin(argv[1],true,&nUin) )
-    d->PluginUIMessage(nUin);
+  }
+  else if( atoid(argv[1], true, &szId, &nPPID, d) )
+    d->PluginUIMessage(szId, nPPID);
   else
   {
     ReportBadBuddy(argv[0],argv[1]);
     return -1;
   }
+  free(szId);
 
   return nRet;
 }
 
+static int fifo_plugin_list(int argc, const char *const *argv, void *data)
+{
+  CICQDaemon *d = (CICQDaemon *) data;
+  PluginsList l;
+  PluginsListIter it;
+
+  d->PluginList(l);
+  for (it = l.begin(); it != l.end(); ++it)
+  {
+    gLog.Info("[%3d] %s\n", (*it)->Id(), (*it)->Name());
+  }
+  return 0;
+}
+
+static int fifo_plugin_load(int argc, const char *const *argv, void *data)
+{
+  CICQDaemon *d = (CICQDaemon *) data;
+  PluginsList l;
+  PluginsListIter it;
+
+  if (argc == 1)
+  {
+    ReportMissingParams(argv[0]);
+    return -1;
+  }
+  
+  char *sz[] = { "licq", NULL };
+  if (d->PluginLoad(argv[1], 1, sz))
+    return 0;
+  
+  gLog.Info("Couldn't load plugin '%s'\n", argv[1]);
+  return -1;
+}
+
+static int fifo_plugin_unload(int argc, const char *const *argv, void *data)
+{
+  CICQDaemon *d = (CICQDaemon *) data;
+  PluginsList l;
+  PluginsListIter it;
+
+  if( argc == 1 )
+  {
+    ReportMissingParams(argv[0]);
+    return -1;
+  }
+  
+  d->PluginList(l);
+  for (it = l.begin(); it != l.end(); ++it)
+  {
+    if (strcmp((*it)->Name(), argv[1]) == 0)
+    {
+      d->PluginShutdown((*it)->Id());
+	  return 0;
+    }
+  }
+  gLog.Info("Couldn't find plugin '%s'\n", argv[1]);
+  return -1;
+}
+
 static int fifo_help ( int argc, const char *const *argv, void *data)
 {
   struct command_t *table = (struct command_t *)data;
@@ -509,22 +720,37 @@ static int fifo_help ( int argc, const char *const *argv, void *data)
 
   if( argc == 1 )
   {
-    gLog.Info("%sFifo commands:\n",L_FIFOxSTR);
+    gLog.Info(tr("%sFifo commands:\n"), L_FIFOxSTR);
     for( i=0; table[i].fnc ; i++ )
       gLog.Info("%s%s\n",L_BLANKxSTR,table[i].szName);
-    gLog.Info("%s: Type `help command'\n",L_FIFOxSTR);
+    gLog.Info(tr("%s: Type `help command'\n"), L_FIFOxSTR);
   }
   else 
   {
-    for( i = 0 ; i < argc ; i++ )
+    for (i = 0 ; i < argc ; i++)
     {
-      j=process_tok(table, argv[i] );
-      if( j >= 0 )
-        gLog.Info("%s %s: help for `%s'\n%s\n",
-                  L_FIFOxSTR,argv[0],argv[i],table[j].szHelp);
+      if (strcmp(argv[i], "all") == 0)
+      {
+        // show help for all commands 
+        j = 0;
+        while (table[j].szName)
+        {
+          gLog.Info(tr("%s %s: help for `%s'\n%s\n"),
+                    L_FIFOxSTR, argv[0], table[j].szName, table[j].szHelp);
+          j++;
+	}
+      }
       else
-        gLog.Info("%s %s: unknown command `%s'\n",
-                  L_FIFOxSTR,argv[0],argv[i]);
+      {
+        // show help for a specific command
+        j = process_tok(table, argv[i]);
+        if (j >= 0)
+          gLog.Info(tr("%s %s: help for `%s'\n%s\n"),
+                    L_FIFOxSTR, argv[0], argv[i], table[j].szHelp);
+        else
+          gLog.Info(tr("%s %s: unknown command `%s'\n"),
+                    L_FIFOxSTR, argv[0], argv[i]);
+      }
     }
   }
   return 0;
@@ -533,21 +759,24 @@ static int fifo_help ( int argc, const char *const *argv, void *data)
 
 static struct command_t fifocmd_table[]=
 {
-  {"status",       fifo_status,       HELP_STATUS,     0},
-  {"auto_response",fifo_auto_response,HELP_AUTO,       0},
-  {"message",      fifo_message,      HELP_MSG,        0},
-  {"url",          fifo_url,          HELP_URL,        0},
-  {"sms",          fifo_sms,          HELP_SMS,        0},
-  {"sms-number",   fifo_sms_number,   HELP_SMS_NUMBER, 0},
-  {"redirect",     fifo_redirect,     HELP_REDIRECT,   0},
-  {"debuglvl",     fifo_debuglvl,     HELP_DEBUGLVL,   0},
-  {"adduser",      fifo_adduser,      HELP_ADDUSER,    0},
-  {"userinfo",     fifo_userinfo,     HELP_USERINFO,   0},
-  {"exit",         fifo_exit,         HELP_EXIT,       0},
-  {"ui_viewevent", fifo_ui_viewevent, HELP_UIVIEWEVENT,0},
-  {"ui_message",   fifo_ui_message,   HELP_UIMESSAGE,  0},
-  {"help",         fifo_help,         HELP_HELP,       1},
-  {NULL,           NULL,              NULL,            0}
+  {"status",       fifo_status,       HELP_STATUS,       0},
+  {"auto_response",fifo_auto_response,HELP_AUTO,         0},
+  {"message",      fifo_message,      HELP_MSG,          0},
+  {"url",          fifo_url,          HELP_URL,          0},
+  {"sms",          fifo_sms,          HELP_SMS,          0},
+  {"sms-number",   fifo_sms_number,   HELP_SMS_NUMBER,   0},
+  {"redirect",     fifo_redirect,     HELP_REDIRECT,     0},
+  {"debuglvl",     fifo_debuglvl,     HELP_DEBUGLVL,     0},
+  {"adduser",      fifo_adduser,      HELP_ADDUSER,      0},
+  {"userinfo",     fifo_userinfo,     HELP_USERINFO,     0},
+  {"exit",         fifo_exit,         HELP_EXIT,         0},
+  {"ui_viewevent", fifo_ui_viewevent, HELP_UIVIEWEVENT,  0},
+  {"ui_message",   fifo_ui_message,   HELP_UIMESSAGE,    0},
+  {"list_plugins", fifo_plugin_list,  HELP_PLUGINLIST,   0},
+  {"load_plugin",  fifo_plugin_load,  HELP_PLUGINLOAD,   0},
+  {"unload_plugin",fifo_plugin_unload,HELP_PLUGINUNLOAD, 0},
+  {"help",         fifo_help,         HELP_HELP,         1},
+  {NULL,           NULL,              NULL,              0}
 };
 
 //-----ProcessFifo--------------------------------------------------------------
@@ -637,14 +866,14 @@ void CICQDaemon::ProcessFifo(char *_szBuf)
   if( szBuf == NULL )
     return ;
 
-  gLog.Info("%sReceived string: `%s'\n", L_FIFOxSTR, szBuf );
+  gLog.Info(tr("%sReceived string: %s"), L_FIFOxSTR, szBuf);
   line2argv(szBuf, argv, &argc, sizeof(argv) / sizeof(argv[0]) );
   index = process_tok(fifocmd_table,argv[0]);
 
   switch( index )
   {
     case CL_UNKNOWN:
-      gLog.Info("%s: '%s' Unknown fifo command. Try 'help'\n",
+      gLog.Info(tr("%s: '%s' Unknown fifo command. Try 'help'\n"),
                 L_FIFOxSTR,argv[0]);
       break;
     case CL_NONE:
