@@ -263,6 +263,7 @@ CICQDaemon::CICQDaemon(CLicq *_licq)
 
   // Misc
   licqConf.ReadBool("UseSS", m_bUseSS, true); // server side list
+  licqConf.ReadBool("SendTypingNotification", m_bSendTN, true);
   licqConf.ReadBool("ReconnectAfterUinClash", m_bReconnectAfterUinClash, false);
 
   // -----OnEvent configuration-----
@@ -328,7 +329,7 @@ CICQDaemon::CICQDaemon(CLicq *_licq)
     unsigned long t;
     licqConf.ReadNum("Reset", t, 0);
     m_nResetTime = t;
-    for (iter = m_sStats.begin(); iter != m_sStats.end(); iter++)
+    for (iter = m_sStats.begin(); iter != m_sStats.end(); ++iter)
     {
       licqConf.ReadNum(iter->m_szTag, iter->m_nTotal, 0);
       iter->Init();
@@ -489,7 +490,7 @@ void CICQDaemon::UnregisterPlugin()
   pthread_mutex_lock(&licq->mutex_plugins);
   for (iter = licq->list_plugins.begin();
        iter != licq->list_plugins.end();
-       iter++)
+       ++iter)
   {
     if ((*iter)->CompareThread(pthread_self()))
     {
@@ -519,7 +520,7 @@ void CICQDaemon::PluginShutdown(int id)
 {
   PluginsListIter iter;
   pthread_mutex_lock(&licq->mutex_plugins);
-  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); iter++)
+  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); ++iter)
   {
     if (id == (*iter)->Id()) (*iter)->Shutdown();
   }
@@ -532,7 +533,7 @@ void CICQDaemon::PluginDisable(int id)
 {
   PluginsListIter iter;
   pthread_mutex_lock(&licq->mutex_plugins);
-  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); iter++)
+  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); ++iter)
   {
     if (id == (*iter)->Id()) (*iter)->Disable();
   }
@@ -545,7 +546,7 @@ void CICQDaemon::PluginEnable(int id)
 {
   PluginsListIter iter;
   pthread_mutex_lock(&licq->mutex_plugins);
-  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); iter++)
+  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); ++iter)
   {
     if (id == (*iter)->Id()) (*iter)->Enable();
   }
@@ -624,7 +625,7 @@ void CICQDaemon::UnregisterProtoPlugin()
   pthread_mutex_lock(&licq->mutex_protoplugins);
   for (iter = licq->list_protoplugins.begin();
        iter != licq->list_protoplugins.end();
-       iter++)
+       ++iter)
   {
     if ((*iter)->CompareThread(pthread_self()))
     {
@@ -662,7 +663,7 @@ void CICQDaemon::ProtoPluginShutdown(unsigned short _nId)
 {
   ProtoPluginsListIter iter;
   pthread_mutex_lock(&licq->mutex_protoplugins);
-  for (iter = licq->list_protoplugins.begin(); iter != licq->list_protoplugins.end(); iter++)
+  for (iter = licq->list_protoplugins.begin(); iter != licq->list_protoplugins.end(); ++iter)
   {
     if ((*iter)->Id() == _nId) (*iter)->Shutdown();
   }
@@ -696,7 +697,7 @@ void CICQDaemon::FlushStats()
 #ifdef SAVE_STATS
   // Verify we need to save anything
   DaemonStatsList::iterator iter;
-  for (iter = m_sStats.begin(); iter != m_sStats.end(); iter++)
+  for (iter = m_sStats.begin(); iter != m_sStats.end(); ++iter)
   {
     if (iter->Dirty()) break;
   }
@@ -707,7 +708,7 @@ void CICQDaemon::FlushStats()
   if (!licqConf.LoadFile(m_szConfigFile)) return;
   licqConf.SetSection("stats");
   licqConf.WriteNum("Reset", (unsigned long)m_nResetTime);
-  for (iter = m_sStats.begin(); iter != m_sStats.end(); iter++)
+  for (iter = m_sStats.begin(); iter != m_sStats.end(); ++iter)
   {
     licqConf.WriteNum(iter->m_szTag, iter->m_nTotal);
     iter->ClearDirty();
@@ -719,7 +720,7 @@ void CICQDaemon::FlushStats()
 void CICQDaemon::ResetStats()
 {
   DaemonStatsList::iterator iter;
-  for (iter = m_sStats.begin(); iter != m_sStats.end(); iter++)
+  for (iter = m_sStats.begin(); iter != m_sStats.end(); ++iter)
   {
     iter->Reset();
   }
@@ -794,6 +795,7 @@ void CICQDaemon::SaveConf()
 
   // Misc
   licqConf.WriteBool("UseSS", m_bUseSS); // server side list
+  licqConf.WriteBool("SendTypingNotification", m_bSendTN); 
   licqConf.WriteBool("ReconnectAfterUinClash", m_bReconnectAfterUinClash);
 
   // save the sound stuff
@@ -1278,7 +1280,7 @@ void CICQDaemon::ChangeUserStatus(ICQUser *u, unsigned long s)
 //-----AddUserEvent-----------------------------------------------------------
 bool CICQDaemon::AddUserEvent(ICQUser *u, CUserEvent *e)
 {
-  if (u->User()) e->AddToHistory(u, D_RECEIVER);
+  if (u->User()) e->AddToHistory(u, LICQ_PPID, D_RECEIVER);
   // Don't log a user event if this user is on the ignore list
   if (u->IgnoreList() ||
       (e->IsMultiRec() && Ignore(IGNORE_MASSMSG)) ||
@@ -1396,7 +1398,7 @@ ICQEvent *CICQDaemon::SendExpectEvent_Server(const char *szId, unsigned long nPP
   {
     pthread_mutex_lock(&mutex_extendedevents);
     std::list<ICQEvent *>::iterator i;
-    for (i = m_lxExtendedEvents.begin(); i != m_lxExtendedEvents.end(); i++)
+    for (i = m_lxExtendedEvents.begin(); i != m_lxExtendedEvents.end(); ++i)
     {
       if (*i == e)
       {
@@ -1435,7 +1437,7 @@ ICQEvent *CICQDaemon::SendExpectEvent_Server(unsigned long nUin, CPacket *packet
   {
     pthread_mutex_lock(&mutex_extendedevents);
     std::list<ICQEvent *>::iterator i;
-    for (i = m_lxExtendedEvents.begin(); i != m_lxExtendedEvents.end(); i++)
+    for (i = m_lxExtendedEvents.begin(); i != m_lxExtendedEvents.end(); ++i)
     {
       if (*i == e)
       {
@@ -1502,7 +1504,7 @@ ICQEvent *CICQDaemon::SendExpectEvent(ICQEvent *e, void *(*fcn)(void *))
       pthread_mutex_lock(&mutex_sendqueue_server);
       list<ICQEvent *>::iterator iter;
       for (iter = m_lxSendQueue_Server.begin();
-           iter != m_lxSendQueue_Server.end(); iter++)
+           iter != m_lxSendQueue_Server.end(); ++iter)
       {
         if (e == *iter)
         {
@@ -1565,7 +1567,7 @@ void CICQDaemon::FailEvents(int sd, int err)
     e = NULL;
     pthread_mutex_lock(&mutex_runningevents);
     list<ICQEvent *>::iterator iter;
-    for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); iter++)
+    for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); ++iter)
     {
       if ((*iter)->m_nSocketDesc == sd)
       {
@@ -1593,11 +1595,32 @@ void CICQDaemon::FailEvents(int sd, int err)
   } while (e != NULL);
 }
 
+/**
+ * Search the running event queue for a specific event by subsequence.
+ */
+bool CICQDaemon::hasServerEvent(unsigned long _nSubSequence)
+{
+  bool hasEvent = false;
+  pthread_mutex_lock(&mutex_runningevents);
+  list<ICQEvent *>::iterator iter;
+  for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); ++iter)
+  {
+    if ((*iter)->CompareSubSequence(_nSubSequence))
+    {
+      hasEvent = true;
+      break;
+    }
+  }
+
+  pthread_mutex_unlock(&mutex_runningevents);
+  return hasEvent;
+}
+ 
 
 //---DoneSrvEvent--------------------------------------------------------------
 /*! \brief Marks the given event as done.
  *
- * Marks the given event as done and removese it from the running events list. 
+ * Marks the given event as done and removes it from the running events list. 
  * This is for new OSCAR server events. 
  * Basically this is DoneEvent (2)
  */
@@ -1606,7 +1629,7 @@ ICQEvent *CICQDaemon::DoneServerEvent(unsigned long _nSubSeq, EventResult _eResu
   pthread_mutex_lock(&mutex_runningevents);
   ICQEvent *e = NULL;
   list<ICQEvent *>::iterator iter;
-  for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); iter++)
+  for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); ++iter)
   {
     if ((*iter)->CompareSubSequence(_nSubSeq) )
     {
@@ -1644,7 +1667,7 @@ ICQEvent *CICQDaemon::DoneEvent(ICQEvent *e, EventResult _eResult)
   pthread_mutex_lock(&mutex_runningevents);
   list<ICQEvent *>::iterator iter;
   bool bFound = false;
-  for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); iter++)
+  for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); ++iter)
   {
     if (e == *iter)
     {
@@ -1665,7 +1688,7 @@ ICQEvent *CICQDaemon::DoneEvent(ICQEvent *e, EventResult _eResult)
 #if 0
   if (m_lxRunningEvents.size()) {
     gLog.Info("doneevents: for: %p pending: \n", e);
-    for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); iter++)
+    for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); ++iter)
     {
       gLog.Info("%p Command: %d SubCommand: %d Sequence: %hu SubSequence: %d: Uin: %lu\n", *iter,
                 (*iter)->Command(), (*iter)->SubCommand(), (*iter)->Sequence(), (*iter)->SubSequence(),
@@ -1716,7 +1739,7 @@ ICQEvent *CICQDaemon::DoneEvent(int _nSD, unsigned short _nSequence, EventResult
   pthread_mutex_lock(&mutex_runningevents);
   ICQEvent *e = NULL;
   list<ICQEvent *>::iterator iter;
-  for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); iter++)
+  for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); ++iter)
   {
     if ((*iter)->CompareEvent(_nSD, _nSequence) )
     {
@@ -1749,7 +1772,7 @@ ICQEvent *CICQDaemon::DoneEvent(unsigned long tag, EventResult _eResult)
   pthread_mutex_lock(&mutex_runningevents);
   ICQEvent *e = NULL;
   list<ICQEvent *>::iterator iter;
-  for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); iter++)
+  for (iter = m_lxRunningEvents.begin(); iter != m_lxRunningEvents.end(); ++iter)
   {
     if ((*iter)->Equals(tag))
     {
@@ -1801,7 +1824,7 @@ void CICQDaemon::ProcessDoneEvent(ICQEvent *e)
     ICQUser *u = gUserManager.FetchUser(e->m_nDestinationUin, LOCK_R);
     if (u != NULL)
     {
-      e->m_pUserEvent->AddToHistory(u, D_SENDER);
+      e->m_pUserEvent->AddToHistory(u, LICQ_PPID, D_SENDER);
       u->SetLastSentEvent();
       m_xOnEventManager.Do(ON_EVENT_MSGSENT, u);
       gUserManager.DropUser(u);
@@ -1931,7 +1954,7 @@ ICQEvent *CICQDaemon::DoneExtendedServerEvent(const unsigned short _nSubSequence
   pthread_mutex_lock(&mutex_extendedevents);
   ICQEvent *e = NULL;
   list<ICQEvent *>::iterator iter;
-  for (iter = m_lxExtendedEvents.begin(); iter != m_lxExtendedEvents.end(); iter++)
+  for (iter = m_lxExtendedEvents.begin(); iter != m_lxExtendedEvents.end(); ++iter)
   {
     if ((*iter)->m_nSubSequence == _nSubSequence)
     {
@@ -1950,7 +1973,7 @@ ICQEvent *CICQDaemon::DoneExtendedEvent(ICQEvent *e, EventResult _eResult)
 {
   pthread_mutex_lock(&mutex_extendedevents);
   list<ICQEvent *>::iterator iter;
-  for (iter = m_lxExtendedEvents.begin(); iter != m_lxExtendedEvents.end(); iter++)
+  for (iter = m_lxExtendedEvents.begin(); iter != m_lxExtendedEvents.end(); ++iter)
   {
     if (e == (*iter))
     {
@@ -1983,7 +2006,7 @@ ICQEvent *CICQDaemon::DoneExtendedEvent(unsigned long tag, EventResult _eResult)
   pthread_mutex_lock(&mutex_extendedevents);
   ICQEvent *e = NULL;
   list<ICQEvent *>::iterator iter;
-  for (iter = m_lxExtendedEvents.begin(); iter != m_lxExtendedEvents.end(); iter++)
+  for (iter = m_lxExtendedEvents.begin(); iter != m_lxExtendedEvents.end(); ++iter)
   {
     if ((*iter)->Equals(tag))
     {
@@ -2026,7 +2049,7 @@ void CICQDaemon::PushPluginEvent(ICQEvent *e)
 {
   PluginsListIter iter;
   pthread_mutex_lock(&licq->mutex_plugins);
-  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); iter++)
+  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); ++iter)
   {
     if ((*iter)->CompareThread(e->thread_plugin))
     {
@@ -2050,7 +2073,7 @@ void CICQDaemon::PushPluginSignal(CICQSignal *s)
 {
   PluginsListIter iter;
   pthread_mutex_lock(&licq->mutex_plugins);
-  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); iter++)
+  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); ++iter)
   {
     if ( (*iter)->CompareMask(s->Signal()) )
       (*iter)->PushSignal(new CICQSignal(s));
@@ -2070,7 +2093,7 @@ CICQSignal *CICQDaemon::PopPluginSignal()
   PluginsListIter iter;
   CICQSignal *s = NULL;
   pthread_mutex_lock(&licq->mutex_plugins);
-  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); iter++)
+  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); ++iter)
   {
     if ( (*iter)->CompareThread(pthread_self()) )
     {
@@ -2092,7 +2115,7 @@ ICQEvent *CICQDaemon::PopPluginEvent()
   PluginsListIter iter;
   ICQEvent *e = NULL;
   pthread_mutex_lock(&licq->mutex_plugins);
-  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); iter++)
+  for (iter = licq->list_plugins.begin(); iter != licq->list_plugins.end(); ++iter)
   {
     if ( (*iter)->CompareThread(pthread_self()) )
     {
@@ -2110,7 +2133,7 @@ void CICQDaemon::PushProtoSignal(CSignal *s, unsigned long _nPPID)
   bool bExists = false;
   pthread_mutex_lock(&licq->mutex_protoplugins);
   for (iter = licq->list_protoplugins.begin(); iter != licq->list_protoplugins.end();
-       iter++)
+       ++iter)
   {
     if ((*iter)->PPID() == _nPPID)
     {
@@ -2135,7 +2158,7 @@ CSignal *CICQDaemon::PopProtoSignal()
   CSignal *s = NULL;
   pthread_mutex_lock(&licq->mutex_protoplugins);
   for (iter = licq->list_protoplugins.begin(); iter != licq->list_protoplugins.end();
-       iter++)
+       ++iter)
   {
     if ((*iter)->CompareThread(pthread_self()))
     {
@@ -2154,7 +2177,7 @@ void CICQDaemon::CancelEvent(unsigned long t)
   pthread_mutex_lock(&mutex_sendqueue_server);
   list<ICQEvent *>::iterator iter;
   for (iter = m_lxSendQueue_Server.begin();
-       iter != m_lxSendQueue_Server.end(); iter++)
+       iter != m_lxSendQueue_Server.end(); ++iter)
   {
     if ((*iter)->Equals(t))
     {
@@ -2263,7 +2286,7 @@ bool CICQDaemon::AddUserConversation(unsigned long _nCID, const char *_szId)
   bool bAdded = false;
   ConversationList::iterator iter;
   pthread_mutex_lock(&mutex_conversations);
-  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); iter++)
+  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); ++iter)
   {
     if ((*iter)->CID() == _nCID)
     {
@@ -2282,7 +2305,7 @@ bool CICQDaemon::AddUserConversation(int _nSocket, const char *_szId)
   bool bAdded = false;
   ConversationList::iterator iter;
   pthread_mutex_lock(&mutex_conversations);
-  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); iter++)
+  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); ++iter)
   {
     if ((*iter)->Socket() == _nSocket)
     {
@@ -2301,7 +2324,7 @@ bool CICQDaemon::RemoveUserConversation(unsigned long _nCID, const char *_szId)
   bool bRemoved = false;
   ConversationList::iterator iter;
   pthread_mutex_lock(&mutex_conversations);
-  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); iter++)
+  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); ++iter)
   {
     if ((*iter)->CID() == _nCID)
     {
@@ -2319,7 +2342,7 @@ bool CICQDaemon::RemoveUserConversation(int _nSocket, const char *_szId)
   bool bRemoved = false;
   ConversationList::iterator iter;
   pthread_mutex_lock(&mutex_conversations);
-  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); iter++)
+  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); ++iter)
   {
     if ((*iter)->Socket() == _nSocket)
     {
@@ -2336,7 +2359,7 @@ CConversation *CICQDaemon::FindConversation(int _nSocket)
 {
   pthread_mutex_lock(&mutex_conversations);
   ConversationList::iterator iter;
-  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); iter++)
+  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); ++iter)
     if ((*iter)->Socket() == _nSocket)
       break;
   pthread_mutex_unlock(&mutex_conversations);
@@ -2348,7 +2371,7 @@ CConversation *CICQDaemon::FindConversation(unsigned long _nCID)
 {
   pthread_mutex_lock(&mutex_conversations);
   ConversationList::iterator iter;
-  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); iter++)
+  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); ++iter)
     if ((*iter)->CID() == _nCID)
       break;
   pthread_mutex_unlock(&mutex_conversations);
@@ -2361,7 +2384,7 @@ bool CICQDaemon::RemoveConversation(unsigned long _nCID)
   bool bDeleted = false;
   pthread_mutex_lock(&mutex_conversations);
   ConversationList::iterator iter;
-  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); iter++)
+  for (iter = m_lConversations.begin(); iter != m_lConversations.end(); ++iter)
   {
     if ((*iter)->CID() == _nCID)
     {
@@ -2391,9 +2414,9 @@ void CICQDaemon::ProcessMessage(ICQUser *u, CBuffer &packet, char *message,
   unsigned short nPort;
 
   // Do we accept it if we are in Occ or DND?
-  ICQOwner *o = gUserManager.FetchOwner(LOCK_R);
-  unsigned short nOwnerStatus = o->Status();
-  gUserManager.DropOwner();
+  // ICQOwner *o = gUserManager.FetchOwner(LOCK_R);
+  // unsigned short nOwnerStatus = o->Status();
+  // gUserManager.DropOwner();
 
   unsigned short nLevel = nMask;
   unsigned long nFlags = ((nMask & ICQ_CMDxSUB_FxMULTIREC) ? E_MULTIxREC : 0)
@@ -2685,7 +2708,7 @@ bool CICQDaemon::WaitForReverseConnection(unsigned short id, unsigned long uin)
 
   std::list<CReverseConnectToUserData *>::iterator iter;
   for (iter = m_lReverseConnect.begin(); iter != m_lReverseConnect.end();
-    iter++)
+    ++iter)
   {
     if ((*iter)->nId == id && (*iter)->nUin == uin)
       break;
@@ -2705,7 +2728,7 @@ bool CICQDaemon::WaitForReverseConnection(unsigned short id, unsigned long uin)
   while (pthread_cond_timedwait(&cond_reverseconnect_done,
     &mutex_reverseconnect, &ts) == 0)
   {
-    for (iter = m_lReverseConnect.begin(); ; iter++)
+    for (iter = m_lReverseConnect.begin(); ; ++iter)
     {
       if (iter == m_lReverseConnect.end())
       {
@@ -2729,7 +2752,7 @@ bool CICQDaemon::WaitForReverseConnection(unsigned short id, unsigned long uin)
 
   // timed out, just remove the record
   for (iter = m_lReverseConnect.begin(); iter != m_lReverseConnect.end();
-    iter++)
+    ++iter)
   {
     if ((*iter)->nId == id && (*iter)->nUin == uin)
     {
