@@ -37,8 +37,8 @@ int CUserEvent::s_nId = 1;
 
 //----CUserEvent::constructor---------------------------------------------------
 CUserEvent::CUserEvent(unsigned short nSubCommand, unsigned short nCommand,
-                       unsigned long nSequence, time_t tTime,
-                       unsigned long nFlags)
+                       unsigned short nSequence, time_t tTime,
+                       unsigned long nFlags, unsigned long nConvoId)
 {
    // Assigned stuff
    m_nSubCommand = nSubCommand;
@@ -46,7 +46,8 @@ CUserEvent::CUserEvent(unsigned short nSubCommand, unsigned short nCommand,
    m_nSequence = nSequence;
    m_tTime = (tTime == TIME_NOW ? time(NULL) : tTime);
    m_nFlags = nFlags;
-
+   m_nConvoId = nConvoId;
+   
    // Initialized stuff
    m_eDir = D_RECEIVER;
    m_szText = NULL;
@@ -134,7 +135,7 @@ int CUserEvent::AddToHistory_Header(direction _nDir, char *szOut)
 }
 
 
-void CUserEvent::AddToHistory_Flush(ICQUser *u, char *szOut, unsigned long nPPID)
+void CUserEvent::AddToHistory_Flush(ICQUser *u, unsigned long nPPID, char *szOut)
 {
   if (u != NULL)
     u->WriteToHistory(szOut);
@@ -152,8 +153,8 @@ void CUserEvent::AddToHistory_Flush(ICQUser *u, char *szOut, unsigned long nPPID
 //=====CEventMsg================================================================
 
 CEventMsg::CEventMsg(const char *_szMessage, unsigned short _nCommand,
-                     time_t _tTime, unsigned long _nFlags)
-   : CUserEvent(ICQ_CMDxSUB_MSG, _nCommand, 0, _tTime, _nFlags)
+                     time_t _tTime, unsigned long _nFlags, unsigned long _nConvoId)
+   : CUserEvent(ICQ_CMDxSUB_MSG, _nCommand, 0, _tTime, _nFlags, _nConvoId)
 {
   m_szMessage = strdup(_szMessage == NULL ? "" : _szMessage);
   
@@ -179,20 +180,21 @@ CEventMsg::~CEventMsg()
   free (m_szMessage);
 }
 
-void CEventMsg::AddToHistory(ICQUser *u, direction _nDir)
+void CEventMsg::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *szOut = new char[ (strlen(m_szMessage) << 1) + EVENT_HEADER_SIZE];
   int nPos = AddToHistory_Header(_nDir, szOut);
   AddStrWithColons(&szOut[nPos], m_szMessage);
-  AddToHistory_Flush(u, szOut);
+  AddToHistory_Flush(u, _nPPID, szOut);
   delete [] szOut;
 }
 
 
-CEventMsg *CEventMsg::Parse(char *sz, unsigned short nCmd, time_t nTime, unsigned long nFlags)
+CEventMsg *CEventMsg::Parse(char *sz, unsigned short nCmd, time_t nTime,
+  unsigned long nFlags, unsigned long nConvoId)
 {
   gTranslator.ServerToClient (sz);
-  return new CEventMsg(sz, nCmd, nTime, nFlags);
+  return new CEventMsg(sz, nCmd, nTime, nFlags, nConvoId);
 }
 
 
@@ -204,10 +206,10 @@ CEventMsg *CEventMsg::Parse(char *sz, unsigned short nCmd, time_t nTime, unsigne
 
 CEventFile::CEventFile(const char *_szFilename, const char *_szFileDescription,
                        unsigned long _nFileSize, ConstFileList &_lFileList,
-                       unsigned long _nSequence, time_t _tTime,
-                       unsigned long _nFlags, unsigned long _nMsgID1,
-                       unsigned long _nMsgID2)
-   : CUserEvent(ICQ_CMDxSUB_FILE, ICQ_CMDxTCP_START, _nSequence, _tTime, _nFlags),
+                       unsigned short _nSequence, time_t _tTime,
+                       unsigned long _nFlags, unsigned long _nConvoId,
+                       unsigned long _nMsgID1, unsigned long _nMsgID2)
+   : CUserEvent(ICQ_CMDxSUB_FILE, ICQ_CMDxTCP_START, _nSequence, _tTime, _nFlags, _nConvoId),
      m_lFileList(_lFileList.begin(), _lFileList.end())
 {
   m_szFilename = strdup(_szFilename == NULL ? "" : _szFilename);
@@ -233,14 +235,14 @@ CEventFile::~CEventFile()
    free (m_szFileDescription);
 }
 
-void CEventFile::AddToHistory(ICQUser *u, direction _nDir)
+void CEventFile::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *szOut = new char[(strlen(m_szFilename) + strlen(m_szFileDescription)) * 2 + 16 + EVENT_HEADER_SIZE];
   int nPos = AddToHistory_Header(_nDir, szOut);
   nPos += sprintf(&szOut[nPos], ":%s\n", m_szFilename);
   nPos += sprintf(&szOut[nPos], ":%lu\n", m_nFileSize);
   AddStrWithColons(&szOut[nPos], m_szFileDescription);
-  AddToHistory_Flush(u, szOut);
+  AddToHistory_Flush(u, _nPPID, szOut);
   delete [] szOut;
 }
 
@@ -250,8 +252,8 @@ void CEventFile::AddToHistory(ICQUser *u, direction _nDir)
 
 CEventUrl::CEventUrl(const char *_szUrl, const char *_szUrlDescription,
                      unsigned short _nCommand, time_t _tTime,
-                     unsigned long _nFlags)
-   : CUserEvent(ICQ_CMDxSUB_URL, _nCommand, 0, _tTime, _nFlags)
+                     unsigned long _nFlags, unsigned long _nConvoId)
+   : CUserEvent(ICQ_CMDxSUB_URL, _nCommand, 0, _tTime, _nFlags, _nConvoId)
 {
    m_szUrl = strdup(_szUrl == NULL ? "" : _szUrl);
    m_szUrlDescription = strdup(_szUrlDescription == NULL ? "" : _szUrlDescription);
@@ -272,19 +274,20 @@ CEventUrl::~CEventUrl()
    free (m_szUrlDescription);
 }
 
-void CEventUrl::AddToHistory(ICQUser *u, direction _nDir)
+void CEventUrl::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *szOut = new char[(strlen(m_szUrlDescription) << 1) +
                    (strlen(m_szUrl) << 1) + EVENT_HEADER_SIZE];
   int nPos = AddToHistory_Header(_nDir, szOut);
   nPos += sprintf(&szOut[nPos], ":%s\n", m_szUrl);
   AddStrWithColons(&szOut[nPos], m_szUrlDescription);
-  AddToHistory_Flush(u, szOut);
+  AddToHistory_Flush(u, _nPPID, szOut);
   delete [] szOut;
 }
 
 
-CEventUrl *CEventUrl::Parse(char *sz, unsigned short nCmd, time_t nTime, unsigned long nFlags)
+CEventUrl *CEventUrl::Parse(char *sz, unsigned short nCmd, time_t nTime,
+  unsigned long nFlags, unsigned long nConvoId)
 {
   // parse the message into url and url description
   char **szUrl = new char*[2]; // desc, url
@@ -296,7 +299,8 @@ CEventUrl *CEventUrl::Parse(char *sz, unsigned short nCmd, time_t nTime, unsigne
 
   // translating string with Translation Table
   gTranslator.ServerToClient(szUrl[0]);
-  CEventUrl *e = new CEventUrl(szUrl[1], szUrl[0], nCmd, nTime, nFlags);
+  CEventUrl *e = new CEventUrl(szUrl[1], szUrl[0], nCmd, nTime,
+    nFlags, nConvoId);
   delete []szUrl;
 
   return e;
@@ -304,10 +308,10 @@ CEventUrl *CEventUrl::Parse(char *sz, unsigned short nCmd, time_t nTime, unsigne
 
 //=====CEventChat===============================================================
 
-CEventChat::CEventChat(const char *szReason, unsigned long nSequence,
+CEventChat::CEventChat(const char *szReason, unsigned short nSequence,
                        time_t tTime, unsigned long nFlags,
-											 unsigned long nMsgID1, unsigned long nMsgID2)
-   : CUserEvent(ICQ_CMDxSUB_CHAT, ICQ_CMDxTCP_START, nSequence, tTime, nFlags)
+                       unsigned long nConvoId, unsigned long nMsgID1, unsigned long nMsgID2)
+   : CUserEvent(ICQ_CMDxSUB_CHAT, ICQ_CMDxTCP_START, nSequence, tTime, nFlags, nConvoId)
 {
   m_szReason = strdup(szReason ==  NULL ? "" : szReason);
   m_szClients = NULL;
@@ -317,10 +321,10 @@ CEventChat::CEventChat(const char *szReason, unsigned long nSequence,
 }
 
 CEventChat::CEventChat(const char *szReason, const char *szClients,
-   unsigned short nPort, unsigned long nSequence,
-   time_t tTime, unsigned long nFlags, unsigned long nMsgID1,
+   unsigned short nPort, unsigned short nSequence,
+   time_t tTime, unsigned long nFlags, unsigned long nConvoId, unsigned long nMsgID1,
    unsigned long nMsgID2)
-   : CUserEvent(ICQ_CMDxSUB_CHAT, ICQ_CMDxTCP_START, nSequence, tTime, nFlags)
+   : CUserEvent(ICQ_CMDxSUB_CHAT, ICQ_CMDxTCP_START, nSequence, tTime, nFlags, nConvoId)
 {
   m_szReason = strdup(szReason ==  NULL ? "" : szReason);
   if (nPort == 0)
@@ -354,12 +358,12 @@ CEventChat::~CEventChat()
 }
 
 
-void CEventChat::AddToHistory(ICQUser *u, direction _nDir)
+void CEventChat::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *szOut = new char[(strlen(Text()) << 1) + EVENT_HEADER_SIZE];
   int nPos = AddToHistory_Header(_nDir, szOut);
   AddStrWithColons(&szOut[nPos], Text());
-  AddToHistory_Flush(u, szOut);
+  AddToHistory_Flush(u, _nPPID, szOut);
   delete [] szOut;
 }
 
@@ -423,7 +427,7 @@ CEventAdded::~CEventAdded()
   free (m_szId);
 }
 
-void CEventAdded::AddToHistory(ICQUser *u, direction _nDir)
+void CEventAdded::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *p = PPIDSTRING(m_nPPID);
   char *szOut = new char[(strlen(m_szAlias) + strlen(m_szFirstName) +
@@ -433,7 +437,7 @@ void CEventAdded::AddToHistory(ICQUser *u, direction _nDir)
   nPos += sprintf(&szOut[nPos], ":%s (%s)\n:%s\n:%s\n:%s\n:%s\n", m_szId,
                   p, m_szAlias, m_szFirstName, m_szLastName, m_szEmail);
   delete [] p;
-  AddToHistory_Flush(u, szOut, m_nPPID);
+  AddToHistory_Flush(u, m_nPPID, szOut);
   delete [] szOut;
 }
 
@@ -509,7 +513,7 @@ CEventAuthRequest::~CEventAuthRequest()
 }
 
 
-void CEventAuthRequest::AddToHistory(ICQUser *u, direction _nDir)
+void CEventAuthRequest::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *p = PPIDSTRING(m_nPPID);
   char *szOut = new char[(strlen(m_szAlias) + strlen(m_szFirstName) +
@@ -522,7 +526,7 @@ void CEventAuthRequest::AddToHistory(ICQUser *u, direction _nDir)
   delete [] p;
 
   AddStrWithColons(&szOut[nPos], m_szReason);
-  AddToHistory_Flush(u, szOut, m_nPPID);
+  AddToHistory_Flush(u, m_nPPID, szOut);
   delete [] szOut;
 }
 
@@ -578,7 +582,7 @@ CEventAuthGranted::~CEventAuthGranted()
   free (m_szId);
 }
 
-void CEventAuthGranted::AddToHistory(ICQUser *u, direction _nDir)
+void CEventAuthGranted::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *p = PPIDSTRING(m_nPPID);
   char *szOut = new char[(strlen(m_szId) + strlen(p) + strlen(m_szMessage))
@@ -588,7 +592,7 @@ void CEventAuthGranted::AddToHistory(ICQUser *u, direction _nDir)
   delete [] p;
 
   AddStrWithColons(&szOut[nPos], m_szMessage);
-  AddToHistory_Flush(u, szOut, m_nPPID);
+  AddToHistory_Flush(u, m_nPPID, szOut);
   delete [] szOut;
 }
 
@@ -644,7 +648,7 @@ CEventAuthRefused::~CEventAuthRefused()
   free (m_szId);
 }
 
-void CEventAuthRefused::AddToHistory(ICQUser *u, direction _nDir)
+void CEventAuthRefused::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *p = PPIDSTRING(m_nPPID);
   char *szOut = new char[(strlen(m_szId) + strlen(p) + strlen(m_szMessage)) * 2 +
@@ -654,7 +658,7 @@ void CEventAuthRefused::AddToHistory(ICQUser *u, direction _nDir)
   delete [] p;
 
   AddStrWithColons(&szOut[nPos], m_szMessage);
-  AddToHistory_Flush(u, szOut, m_nPPID);
+  AddToHistory_Flush(u, m_nPPID, szOut);
   delete [] szOut;
 }
 
@@ -688,7 +692,7 @@ CEventWebPanel::~CEventWebPanel()
 }
 
 
-void CEventWebPanel::AddToHistory(ICQUser *u, direction _nDir)
+void CEventWebPanel::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *szOut = new char[(strlen(m_szName) + strlen(m_szEmail) +
                     strlen(m_szMessage)) * 2 +
@@ -696,7 +700,7 @@ void CEventWebPanel::AddToHistory(ICQUser *u, direction _nDir)
   int nPos = AddToHistory_Header(_nDir, szOut);
   nPos += sprintf(&szOut[nPos], ":%s\n:%s\n", m_szName, m_szEmail);
   AddStrWithColons(&szOut[nPos], m_szMessage);
-  AddToHistory_Flush(u, szOut);
+  AddToHistory_Flush(u, _nPPID, szOut);
   delete [] szOut;
 }
 
@@ -728,7 +732,7 @@ CEventEmailPager::~CEventEmailPager()
   free (m_szMessage);
 }
 
-void CEventEmailPager::AddToHistory(ICQUser *u, direction _nDir)
+void CEventEmailPager::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *szOut = new char[(strlen(m_szName) + strlen(m_szEmail) +
                     strlen(m_szMessage)) * 2 +
@@ -736,7 +740,7 @@ void CEventEmailPager::AddToHistory(ICQUser *u, direction _nDir)
   int nPos = AddToHistory_Header(_nDir, szOut);
   nPos += sprintf(&szOut[nPos], ":%s\n:%s\n", m_szName, m_szEmail);
   AddStrWithColons(&szOut[nPos], m_szMessage);
-  AddToHistory_Flush(u, szOut);
+  AddToHistory_Flush(u, _nPPID, szOut);
   delete [] szOut;
 }
 
@@ -759,9 +763,9 @@ void CEventContactList::CreateDescription()
   if (m_szText) delete [] m_szText;
   m_szText = new char [m_vszFields.size() * 32 + 128];
   char *szEnd = m_szText;
-  szEnd += sprintf(m_szText, tr("Contact list (%d contacts):\n"), m_vszFields.size());
+  szEnd += sprintf(m_szText, tr("Contact list (%d contacts):\n"), int(m_vszFields.size()));
   ContactList::const_iterator iter;
-  for (iter = m_vszFields.begin(); iter != m_vszFields.end(); iter++)
+  for (iter = m_vszFields.begin(); iter != m_vszFields.end(); ++iter)
   {
     szEnd += sprintf(szEnd, "%s (%s)\n", (*iter)->Alias(), (*iter)->IdString());
   }
@@ -771,18 +775,18 @@ void CEventContactList::CreateDescription()
 CEventContactList::~CEventContactList()
 {
   ContactList::iterator iter;
-  for (iter = m_vszFields.begin(); iter != m_vszFields.end(); iter++)
+  for (iter = m_vszFields.begin(); iter != m_vszFields.end(); ++iter)
     delete *iter;
 }
 
 
-void CEventContactList::AddToHistory(ICQUser *u, direction _nDir)
+void CEventContactList::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   unsigned long nPPID = LICQ_PPID;
   char *szOut = new char[m_vszFields.size() * 32 + EVENT_HEADER_SIZE];
   int nPos = AddToHistory_Header(_nDir, szOut);
   ContactList::const_iterator iter;
-  for (iter = m_vszFields.begin(); iter != m_vszFields.end(); iter++)
+  for (iter = m_vszFields.begin(); iter != m_vszFields.end(); ++iter)
   {
     char *p = PPIDSTRING((*iter)->PPID());
     nPPID = (*iter)->PPID();
@@ -790,7 +794,7 @@ void CEventContactList::AddToHistory(ICQUser *u, direction _nDir)
       p, (*iter)->Alias());
     delete [] p;
   }
-  AddToHistory_Flush(u, szOut, nPPID);
+  AddToHistory_Flush(u, nPPID, szOut);
   delete [] szOut;
 }
 
@@ -842,7 +846,7 @@ CEventSms::~CEventSms()
   free(m_szMessage);
 }
 
-void CEventSms::AddToHistory(ICQUser *u, direction _nDir)
+void CEventSms::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *szOut = new char[ (strlen(m_szNumber) << 1) + 
 			  (strlen(m_szMessage) << 1) +
@@ -850,7 +854,7 @@ void CEventSms::AddToHistory(ICQUser *u, direction _nDir)
   int nPos = AddToHistory_Header(_nDir, szOut);
   nPos += sprintf(&szOut[nPos], ":%s\n", m_szNumber);
   AddStrWithColons(&szOut[nPos], m_szMessage);
-  AddToHistory_Flush(u, szOut);
+  AddToHistory_Flush(u, _nPPID, szOut);
   delete [] szOut;
 }
 
@@ -901,14 +905,14 @@ void CEventServerMessage::CreateDescription()
           m_szEmail, m_szMessage);
 }
 
-void CEventServerMessage::AddToHistory(ICQUser *u, direction _nDir)
+void CEventServerMessage::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
 {
   char *szOut = new char[(strlen(m_szName) + strlen(m_szEmail) +
                          (strlen(m_szMessage) * 2) + EVENT_HEADER_SIZE)];
   int nPos = AddToHistory_Header(_nDir, szOut);
   nPos += sprintf(&szOut[nPos], ":%s\n%s\n", m_szName, m_szEmail);
   AddStrWithColons(&szOut[nPos], m_szMessage);
-  AddToHistory_Flush(u, szOut);
+  AddToHistory_Flush(u, _nPPID, szOut);
   delete [] szOut;
 }
 
@@ -931,6 +935,62 @@ CEventServerMessage *CEventServerMessage::Parse(char *sz, unsigned short nCmd,
 }
 
 
+//=====CEventEmailAlert=====================================================
+CEventEmailAlert::CEventEmailAlert(const char *_szName, const char *_szTo,
+  const char *_szEmail, const char *_szSubject, time_t _tTime,
+  const char *_szMSPAuth, const char *_szSID, const char *_szKV,
+  const char *_szId, const char *_szPostURL, const char *_szMsgURL,
+  const char *_szCreds, unsigned long _nSessionLength)
+   : CUserEvent(ICQ_CMDxSUB_EMAILxALERT, ICQ_CMDxTCP_START, 0, _tTime, 0)
+{
+  m_szName = strdup(_szName == NULL ? "" : _szName);
+  m_szTo = strdup(_szTo == NULL ? "" : _szTo);
+  m_szEmail = strdup(_szEmail == NULL ? "" : _szEmail);
+  m_szSubject = strdup(_szSubject == NULL ? "" : _szSubject);
+  m_szMSPAuth = strdup(_szMSPAuth == NULL ? "" : _szMSPAuth);
+  m_szSID = strdup(_szSID == NULL ? "" : _szSID);
+  m_szKV = strdup(_szKV == NULL ? "" : _szKV);
+  m_szId = strdup(_szId == NULL ? "" : _szId);
+  m_szPostURL = strdup(_szPostURL == NULL ? "" : _szPostURL);
+  m_szMsgURL = strdup(_szMsgURL == NULL ? "" : _szMsgURL);
+  m_szCreds = strdup(_szCreds == NULL ? "" : _szCreds);
+  m_nSessionLength = _nSessionLength;
+}
+
+CEventEmailAlert::~CEventEmailAlert()
+{
+  free(m_szName);
+  free(m_szTo);
+  free(m_szEmail);
+  free(m_szSubject);
+  free(m_szMSPAuth);
+  free(m_szSID);
+  free(m_szKV);
+  free(m_szId);
+  free(m_szPostURL);
+  free(m_szMsgURL);
+  free(m_szCreds);
+}
+
+void CEventEmailAlert::CreateDescription()
+{
+  if (m_szText) delete [] m_szText;
+  m_szText = new char[strlen(m_szName) + strlen(m_szEmail) + strlen(m_szSubject) + 64];
+  sprintf(m_szText, tr("New Email from %s (%s):\nSubject: %s\n"), m_szName,
+          m_szEmail, m_szSubject);
+}
+
+void CEventEmailAlert::AddToHistory(ICQUser *u, unsigned long _nPPID, direction _nDir)
+{
+  char *szOut = new char[(strlen(m_szName) + strlen(m_szEmail) +
+                         (strlen(m_szSubject) * 2) + EVENT_HEADER_SIZE)];
+  int nPos = AddToHistory_Header(_nDir, szOut);
+  nPos += sprintf(&szOut[nPos], ":%s\n:%s\n", m_szName, m_szEmail);
+  AddStrWithColons(&szOut[nPos], m_szSubject);
+  AddToHistory_Flush(u, _nPPID, szOut);
+  delete [] szOut;
+}
+
 //=====EventPlugin=============================================================
 CEventPlugin::CEventPlugin(const char *sz, unsigned short nSubCommand,
    time_t tTime, unsigned long nFlags)
@@ -952,7 +1012,7 @@ CEventPlugin::~CEventPlugin()
   free(m_sz);
 }
 
-void CEventPlugin::AddToHistory(ICQUser *, direction)
+void CEventPlugin::AddToHistory(ICQUser *, unsigned long, direction)
 {
   // Don't write these to the history file
 }
@@ -983,7 +1043,7 @@ CEventUnknownSysMsg::~CEventUnknownSysMsg()
   free(m_szMsg);
 }
 
-void CEventUnknownSysMsg::AddToHistory(ICQUser * /*u*/, direction /*_nDir*/)
+void CEventUnknownSysMsg::AddToHistory(ICQUser * /*u*/, unsigned long /*_nPPID*/, direction /*_nDir*/)
 {
 /*  char *szOut = new char[strlen(m_szMsg) * 2 + 16 + EVENT_HEADER_SIZE];
   int nPos = sprintf(szOut, "[ %c | 0000 | %04d | %04d | %lu ]\n",
@@ -991,7 +1051,7 @@ void CEventUnknownSysMsg::AddToHistory(ICQUser * /*u*/, direction /*_nDir*/)
           m_nCommand, (unsigned short)(m_nFlags >> 16), m_tTime);
   nPos += sprintf(&szOut[nPos], ":%lu\n", m_nUin);
   AddStrWithColons(&szOut[nPos], m_szMsg);
-  AddToHistory_Flush(u, szOut);
+  AddToHistory_Flush(u, _nPPID, szOut);
   delete [] szOut;*/
 }
 
