@@ -67,11 +67,12 @@ void COnEventManager::SetParameters(const char *_szCommand, const char **_aszPar
 void COnEventManager::Do(unsigned short _nEvent, ICQUser *u)
 {
   unsigned long nPPID = LICQ_PPID;
-  //if (u)
-  //  nPPID = u->PPID();
+  if (u)
+    nPPID = u->PPID();
 
   // Check if globally command should be run
   ICQOwner *o = gUserManager.FetchOwner(nPPID, LOCK_R);
+  if (!o) return;
   unsigned long s = o->Status();
 
   // Messy Mode / Accept Stuff by Andypoo (andypoo@ihug.com.au)
