@@ -71,7 +71,8 @@ using namespace std;
 
 char *ip_ntoa(unsigned long in, char *buf)
 {
-  return inet_ntoa_r( *(struct in_addr *)&in, buf);
+  in_addr _in = { in };
+  return inet_ntoa_r(_in, buf);
 }
 
 char *inet_ntoa_r(struct in_addr in, char *buf)
@@ -104,7 +105,7 @@ void CSocketSet::Set(int _nSD)
   Lock();
   FD_SET(_nSD, &sFd);
   list<int>::iterator i = lFd.begin();
-  while (i != lFd.end() && _nSD < *i) i++;
+  while (i != lFd.end() && _nSD < *i) ++i;
   lFd.insert(i, _nSD);
   Unlock();
 }
@@ -114,7 +115,7 @@ void CSocketSet::Clear (int _nSD)
   Lock();
   FD_CLR(_nSD, &sFd);
   list<int>::iterator i = lFd.begin();
-  while (i != lFd.end() && *i != _nSD) i++;
+  while (i != lFd.end() && *i != _nSD) ++i;
   if (i != lFd.end()) lFd.erase(i);
   Unlock();
 }
@@ -1228,10 +1229,13 @@ bool TCPSocket::SecureListen()
       case SSL_ERROR_SSL:
         err = ERR_get_error_line(&file, &line);
         gLog.Warn("%sSSL_accept error = %lx, %s:%i\n", L_SSLxSTR, err, file, line);
+        gLog.Warn("%s%s\n", L_SSLxSTR, ERR_error_string(err, 0));
         ERR_clear_error();
         break;
       default:
+        err = ERR_get_error();
         gLog.Warn("%sSSL_accept error %d, SSL_%d\n", L_SSLxSTR, i, j);
+        gLog.Warn("%s%s\n", L_SSLxSTR, ERR_error_string(err, 0));
         break;
     }
     return false;
@@ -1332,7 +1336,7 @@ INetSocket *CSocketHashTable::Retrieve(int _nSd)
 
   int nSd;
   list<INetSocket *>::iterator iter;
-  for (iter = l.begin(); iter != l.end(); iter++)
+  for (iter = l.begin(); iter != l.end(); ++iter)
   {
     (*iter)->Lock();
     nSd = (*iter)->Descriptor();
@@ -1363,7 +1367,7 @@ void CSocketHashTable::Remove(int _nSd)
   list<INetSocket *> &l = m_vlTable[HashValue(_nSd)];
   int nSd;
   list<INetSocket *>::iterator iter;
-  for (iter = l.begin(); iter != l.end(); iter++)
+  for (iter = l.begin(); iter != l.end(); ++iter)
   {
     (*iter)->Lock();
     nSd = (*iter)->Descriptor();
