@@ -226,7 +226,7 @@ char *CTranslator::ToUnicode(char *_sz, char *_szFrom)
   char *szIn = _sz, *szOut = szNewStr;
   iconv_t tr;
 
-  nInSize = nLen;
+  nInSize = strlen(_sz);
   nOutSize = nLen;
 
   // Clean up for iconv, remove any spaces
@@ -241,17 +241,45 @@ char *CTranslator::ToUnicode(char *_sz, char *_szFrom)
   szFrom[j] = '\0';
   
   
-  tr = iconv_open("UTF-8", szFrom);
-  size_t ret = iconv(tr, &szIn, &nInSize, &szOut, &nOutSize);
-  iconv_close(tr);
-
-  if (ret == (size_t)(-1))
+  tr = iconv_open("UTF-8", szFrom[0] == '\0' ? "" : szFrom);
+  if (tr != (iconv_t)-1)
   {
-    tr = iconv_open("UCS-2BE", szFrom);
-    iconv(tr, &szIn, &nInSize, &szOut, &nOutSize);
+    size_t ret = iconv(tr, (ICONV_CONST char**)&szIn, &nInSize, &szOut, &nOutSize);
     iconv_close(tr);
-  }
 
+    if (ret == (size_t)(-1))
+    {
+      //set new values because iconv() is changing them
+      szIn = _sz;
+      szOut = szNewStr; 
+      nInSize = strlen(_sz);
+      nOutSize = nLen;
+      
+      tr = iconv_open("UCS-2BE", szFrom[0] == '\0' ? "" : szFrom);
+      if (tr == (iconv_t)-1)
+      {
+        iconv(tr, (ICONV_CONST char**)&szIn, &nInSize, &szOut, &nOutSize);
+        iconv_close(tr);
+      }
+      else
+      {
+        tr = iconv_open("UCS-2BE", "UTF-8");
+        size_t ret = iconv(tr, (ICONV_CONST char**)&szIn, &nInSize, &szOut, &nOutSize);
+        iconv_close(tr);
+        if (ret == (size_t)(-1))
+        {
+          gLog.Error("Error encoding (%s) to UCS-2BE from %s (unsupported conversion)\n",
+                     szIn, szFrom);
+        }
+      }
+    }
+  }
+  else
+  {
+    gLog.Error("Error encoding to UTF-8 from %s (unsupported conversion)\n",
+               szFrom);
+  }
+  
   *szOut = '\0';
 
   delete [] szFrom;
@@ -287,16 +315,32 @@ char *CTranslator::FromUnicode(char *_sz, char *_szTo)
 
 
   tr = iconv_open(szTo, "UTF-8");
-  size_t ret = iconv(tr, &szIn, &nInSize, &szOut, &nOutSize);
-  iconv_close(tr);
-
-  if (ret == (size_t)(-1))
+  if (tr != (iconv_t)-1)
   {
-    tr = iconv_open(szTo, "UCS-2BE");
-    iconv(tr, &szIn, &nInSize, &szOut, &nOutSize);
+    size_t ret = iconv(tr, (ICONV_CONST char**)&szIn, &nInSize, &szOut, &nOutSize);
     iconv_close(tr);
-  }
 
+    if (ret == (size_t)(-1))
+    {
+      tr = iconv_open(szTo, "UCS-2BE");
+      if (tr != (iconv_t)-1)
+      {
+        iconv(tr, (ICONV_CONST char**)&szIn, &nInSize, &szOut, &nOutSize);
+        iconv_close(tr);
+      }
+      else
+      {
+        gLog.Error("Error encoding to %s from UCS-2BE (unsupported conversion)\n",
+                   szTo);
+      }
+    }
+  }
+  else
+  {
+    gLog.Error("Error encoding to %s from UTF-8 (unsupported conversion)\n",
+               szTo);
+  }
+  
   *szOut = '\0';
 
   delete [] szTo;
@@ -319,12 +363,30 @@ char *CTranslator::FromUTF16(char *_sz, int nMsgLen)
   nOutSize = nLen * 2;
   
   tr = iconv_open("", "UCS-2BE");
-  size_t ret = iconv(tr, &szIn, &nInSize, &szOut, &nOutSize);
-  iconv_close(tr);
-  
-  if (ret == (size_t)(-1))
+  if (tr != (iconv_t)-1)
   {
-    gLog.Error("Error decoding a UTF-16 message.\n");
+    size_t ret = iconv(tr, (ICONV_CONST char**)&szIn, &nInSize, &szOut, &nOutSize);
+    iconv_close(tr);
+  
+    if (ret == (size_t)(-1))
+    {
+      // Try decoding to UTF8
+      tr = iconv_open("UTF-8", "UCS-2BE");
+      if (tr != (iconv_t)-1)
+      {
+        size_t ret = iconv(tr, (ICONV_CONST char**)&szIn, &nInSize, &szOut, &nOutSize);
+        iconv_close(tr);
+
+        if (ret == (size_t)(-1))
+          gLog.Error("Error decoding a UCS-2BE message.\n");
+      }
+      else
+        gLog.Error("Error decoding from UCS-2BE to UTF-8 (unsupported conversion)\n");
+    }
+  }
+  else
+  {
+    gLog.Error("Error decoding from UCS-2BE (unsupported conversion)\n");
   }
   
   *szOut = '\0';
@@ -344,16 +406,37 @@ char *CTranslator::ToUTF16(char *_sz, char *_szEncoding, size_t &nSize)
   
   nInSize = strlen(szIn);
   nOutSize = nLen;
+
+  // Clean up for iconv, remove any spaces
+  int nFromLen = strlen(_szEncoding);
+  int j = 0;
+  char *szFrom = new char [nFromLen+1];
+  for (int i = 0; i < nFromLen; i++)
+  {
+    if (_szEncoding[i] != ' ')
+      szFrom[j++] = _szEncoding[i];
+  }
+  szFrom[j] = '\0';
   
-  tr = iconv_open("UCS-2BE", _szEncoding);
-  size_t ret = iconv(tr, &szIn, &nInSize, &szOut, &nOutSize);
-  iconv_close(tr);
+  tr = iconv_open("UCS-2BE", szFrom);
+  if (tr != (iconv_t)-1)
+  {
+    size_t ret = iconv(tr, (ICONV_CONST char**)&szIn, &nInSize, &szOut, &nOutSize);
+    iconv_close(tr);
   
-  if (ret == (size_t)-1)
-    gLog.Error("Error encoding to UTF-16 from %s\n", _szEncoding);
+    if (ret == (size_t)-1)
+      gLog.Error("Error encoding to UTF-16 from %s\n", szFrom);
+  }
+  else
+  {
+    gLog.Error("Error encoding to UTF-16 from %s (unsupported conversion)\n",
+               szFrom);
+  }
 
   *szOut = '\0';
   nSize = nLen - nOutSize;
+
+  delete [] szFrom;
   
   return szNewStr;
 }
